@@ -1,5 +1,5 @@
 /* file.c --- File based Shisa database.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -152,7 +152,7 @@ shisa_file_done (Shisa * dbh, void *state)
    UTF-8 strings.  The caller must deallocate the strings. */
 int
 shisa_file_enumerate_realms (Shisa * dbh,
-			     void *state, char ***realms, size_t * nrealms)
+			     void *state, char ***realms, size_t *nrealms)
 {
   Shisa_file *info = state;
 
@@ -169,7 +169,7 @@ int
 shisa_file_enumerate_principals (Shisa * dbh,
 				 void *state,
 				 const char *realm,
-				 char ***principals, size_t * nprincipals)
+				 char ***principals, size_t *nprincipals)
 {
   Shisa_file *info = state;
 
@@ -423,7 +423,7 @@ read_key (Shisa * dbh,
   Shisa_key tmpkey;
   FILE *fh;
   char *file;
-  unsigned passwdlen;
+  size_t passwdlen;
   char junk;
   int rc;
 
@@ -435,9 +435,10 @@ read_key (Shisa * dbh,
 
   memset (&tmpkey, 0, sizeof (tmpkey));
 
-  rc = fscanf (fh, "%u %u %u %u %u %u", &tmpkey.etype, &tmpkey.keylen,
-	       &tmpkey.saltlen, &tmpkey.str2keyparamlen, &passwdlen,
-	       &tmpkey.priority);
+  rc =
+    fscanf (fh, "%" PRIi32 " %zu %zu %zu %zu %d", &tmpkey.etype,
+	    &tmpkey.keylen, &tmpkey.saltlen, &tmpkey.str2keyparamlen,
+	    &passwdlen, &tmpkey.priority);
   if (rc != 5 && rc != 6)
     return SHISA_NO_KEY;
 
@@ -530,7 +531,7 @@ shisa_file_keys_find (Shisa * dbh,
 		      const char *realm,
 		      const char *principal,
 		      const Shisa_key * hint,
-		      Shisa_key *** keys, size_t * nkeys)
+		      Shisa_key *** keys, size_t *nkeys)
 {
   Shisa_file *info = state;
   Shisa_key *tmpkey;
@@ -600,7 +601,8 @@ shisa_file_key_add (Shisa * dbh,
   do
     {
       free (file);
-      asprintf (&file, "keys/%d-%d-%d.key", key->kvno, key->etype, num++);
+      asprintf (&file, "keys/%" PRIu32 "-%d-%lu.key", key->kvno, key->etype,
+		num++);
     }
   while (_shisa_isfile4 (info->path, realm, principal, file));
   fh = _shisa_fopen4 (info->path, realm, principal, file, "w");
@@ -611,7 +613,7 @@ shisa_file_key_add (Shisa * dbh,
       return SHISA_ADD_KEY_ERROR;
     }
 
-  fprintf (fh, "%u %u %u %u %u %u\n", key->etype, key->keylen,
+  fprintf (fh, "%" PRIi32 " %zu %zu %zu %zu %d\n", key->etype, key->keylen,
 	   key->saltlen, key->str2keyparamlen, passwdlen, key->priority);
   if (key->keylen > 0)
     fwrite (key->key, 1, key->keylen, fh);
