@@ -1,5 +1,5 @@
 /* fileutil.c --- Utility functions used by file.c.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -427,8 +427,7 @@ _shisa_uint32link4 (const char *path1,
 }
 
 static int
-ls_1 (const char *path, int onlydir, char ***files, size_t * nfiles,
-      DIR * dir)
+ls_1 (const char *path, int onlydir, char ***files, size_t *nfiles, DIR * dir)
 {
   struct dirent *de;
 
@@ -468,7 +467,7 @@ ls_1 (const char *path, int onlydir, char ***files, size_t * nfiles,
 }
 
 static int
-ls (const char *path, int onlydir, char ***files, size_t * nfiles)
+ls (const char *path, int onlydir, char ***files, size_t *nfiles)
 {
   DIR *dir;
   int rc;
@@ -510,14 +509,14 @@ ls (const char *path, int onlydir, char ***files, size_t * nfiles)
 }
 
 int
-_shisa_ls (const char *path, char ***files, size_t * nfiles)
+_shisa_ls (const char *path, char ***files, size_t *nfiles)
 {
   return ls (path, 0, files, nfiles);
 }
 
 int
 _shisa_ls2 (const char *path, const char *realm,
-	    char ***files, size_t * nfiles)
+	    char ***files, size_t *nfiles)
 {
   char *saferealm = escape_filename (realm);
   char *tmp;
@@ -535,7 +534,7 @@ _shisa_ls2 (const char *path, const char *realm,
 
 int
 _shisa_ls3 (const char *path, const char *realm,
-	    const char *principal, char ***files, size_t * nfiles)
+	    const char *principal, char ***files, size_t *nfiles)
 {
   char *saferealm = escape_filename (realm);
   char *safeprincipal = escape_filename (principal);
@@ -556,7 +555,7 @@ _shisa_ls3 (const char *path, const char *realm,
 int
 _shisa_ls4 (const char *path, const char *realm,
 	    const char *principal, const char *path4,
-	    char ***files, size_t * nfiles)
+	    char ***files, size_t *nfiles)
 {
   char *saferealm = escape_filename (realm);
   char *safeprincipal = escape_filename (principal);
@@ -575,14 +574,14 @@ _shisa_ls4 (const char *path, const char *realm,
 }
 
 int
-_shisa_lsdir (const char *path, char ***files, size_t * nfiles)
+_shisa_lsdir (const char *path, char ***files, size_t *nfiles)
 {
   return ls (path, 1, files, nfiles);
 }
 
 int
 _shisa_lsdir2 (const char *path, const char *realm,
-	       char ***files, size_t * nfiles)
+	       char ***files, size_t *nfiles)
 {
   char *saferealm = escape_filename (realm);
   char *tmp;
