@@ -1,5 +1,5 @@
 /* shisa.h --- Header file for concurrent write-safe user information database.
- * Copyright (C) 2003-2013 Simon Josefsson
+ * Copyright (C) 2003-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -21,11 +21,11 @@
  */
 
 #ifndef SHISA_H
-#define SHISA_H
+# define SHISA_H
 
-#include <stddef.h>		/* size_t */
-#include <time.h>		/* time_t */
-#include <shishi-int.h>		/* int32_t, uint32_t */
+# include <stddef.h>		/* size_t */
+# include <time.h>		/* time_t */
+# include <stdint.h>		/* int32_t, uint32_t */
 
 /* Error codes */
 enum Shisa_rc
@@ -116,7 +116,7 @@ extern void shisa_keys_free (Shisa * dbh, Shisa_key ** keys, size_t nkeys);
 /* Return a list of all realm names in backend, as zero-terminated
    UTF-8 strings.  The caller must deallocate the strings. */
 extern int shisa_enumerate_realms (Shisa * dbh,
-				   char ***realms, size_t * nrealms);
+				   char ***realms, size_t *nrealms);
 
 /* Return a list of all principals in realm in backend, as
    zero-terminated UTF-8 strings.  The caller must deallocate the
@@ -124,7 +124,7 @@ extern int shisa_enumerate_realms (Shisa * dbh,
 extern int shisa_enumerate_principals (Shisa * dbh,
 				       const char *realm,
 				       char ***principals,
-				       size_t * nprincipals);
+				       size_t *nprincipals);
 
 /**************************************** Functions operating on principals. */
 
@@ -162,7 +162,7 @@ extern int shisa_keys_find (Shisa * dbh,
 			    const char *realm,
 			    const char *principal,
 			    const Shisa_key * hint,
-			    Shisa_key *** keys, size_t * nkeys);
+			    Shisa_key *** keys, size_t *nkeys);
 
 /* Add key for PRINCIPAL@REALM. */
 extern int shisa_key_add (Shisa * dbh,
