@@ -1,6 +1,6 @@
 /* client-priv.c --- Sample Shishi authenticated client, with privacy
  *                   protected application data exchange.
- * Copyright (C) 2003-2013 Simon Josefsson
+ * Copyright (C) 2003-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -21,6 +21,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
