@@ -1,5 +1,5 @@
 /* client.c --- Sample client with authentication using Shishi.
- * Copyright (C) 2003-2013 Simon Josefsson
+ * Copyright (C) 2003-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -20,6 +20,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
