@@ -1,5 +1,5 @@
 /* authenticator.c --- Functions for authenticators.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -558,7 +558,7 @@ shishi_authenticator_seqnumber_set (Shishi * handle,
 int
 shishi_authenticator_client (Shishi * handle,
 			     Shishi_asn1 authenticator,
-			     char **client, size_t * clientlen)
+			     char **client, size_t *clientlen)
 {
   return shishi_principal_name (handle, authenticator,
 				"cname", client, clientlen);
@@ -584,7 +584,7 @@ shishi_authenticator_client (Shishi * handle,
 int
 shishi_authenticator_clientrealm (Shishi * handle,
 				  Shishi_asn1 authenticator,
-				  char **client, size_t * clientlen)
+				  char **client, size_t *clientlen)
 {
   return shishi_principal_name_realm (handle,
 				      authenticator, "cname",
@@ -624,7 +624,7 @@ int
 shishi_authenticator_cksum (Shishi * handle,
 			    Shishi_asn1 authenticator,
 			    int32_t * cksumtype,
-			    char **cksum, size_t * cksumlen)
+			    char **cksum, size_t *cksumlen)
 {
   int res;
 
@@ -803,7 +803,7 @@ shishi_authenticator_add_authorizationdata (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  asprintf (&format, "authorization-data.?%ld.ad-type", i);
+  asprintf (&format, "authorization-data.?%zu.ad-type", i);
   res = shishi_asn1_write_integer (handle, authenticator, format, adtype);
   if (res != SHISHI_OK)
     {
@@ -811,7 +811,7 @@ shishi_authenticator_add_authorizationdata (Shishi * handle,
       return res;
     }
 
-  sprintf (format, "authorization-data.?%ld.ad-data", i);
+  sprintf (format, "authorization-data.?%zu.ad-data", i);
   res = shishi_asn1_write (handle, authenticator, format, addata, addatalen);
   free (format);
   if (res != SHISHI_OK)
@@ -838,7 +838,7 @@ int
 shishi_authenticator_authorizationdata (Shishi * handle,
 					Shishi_asn1 authenticator,
 					int32_t * adtype,
-					char **addata, size_t * addatalen,
+					char **addata, size_t *addatalen,
 					size_t nth)
 {
   char *format;
@@ -853,13 +853,13 @@ shishi_authenticator_authorizationdata (Shishi * handle,
   if (nth > i)
     return SHISHI_OUT_OF_RANGE;
 
-  asprintf (&format, "authorization-data.?%ld.ad-type", nth);
+  asprintf (&format, "authorization-data.?%zu.ad-type", nth);
   res = shishi_asn1_read_int32 (handle, authenticator, format, adtype);
   free (format);
   if (res != SHISHI_OK)
     return res;
 
-  asprintf (&format, "authorization-data.?%ld.ad-data", i);
+  asprintf (&format, "authorization-data.?%zu.ad-data", i);
   res = shishi_asn1_read (handle, authenticator, format, addata, addatalen);
   free (format);
   if (res != SHISHI_OK)
