@@ -1,5 +1,5 @@
 /* crypto.c --- Crypto functions.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -133,7 +133,7 @@ static int
 simplified_hmac (Shishi * handle,
 		 Shishi_key * key,
 		 const char *in, size_t inlen,
-		 char **outhash, size_t * outhashlen)
+		 char **outhash, size_t *outhashlen)
 {
   *outhashlen = shishi_checksum_cksumlen
     (shishi_cipher_defaultcksumtype (shishi_key_type (key)));
@@ -228,7 +228,7 @@ _shishi_simplified_derivekey (Shishi * handle,
 
   if (VERBOSECRYPTO (handle))
     {
-      printf ("\t ;; simplified_derivekey out (%d):\n",
+      printf ("\t ;; simplified_derivekey out (%zu):\n",
 	      shishi_key_length (derivedkey));
       _shishi_hexprint (shishi_key_value (derivedkey),
 			shishi_key_length (derivedkey));
@@ -241,9 +241,9 @@ int
 _shishi_simplified_dencrypt (Shishi * handle,
 			     Shishi_key * key,
 			     const char *iv, size_t ivlen,
-			     char **ivout, size_t * ivoutlen,
+			     char **ivout, size_t *ivoutlen,
 			     const char *in, size_t inlen,
-			     char **out, size_t * outlen, int decryptp)
+			     char **out, size_t *outlen, int decryptp)
 {
   int rc;
   char *pt;
@@ -315,9 +315,9 @@ _shishi_simplified_encrypt (Shishi * handle,
 			    Shishi_key * key,
 			    int keyusage,
 			    const char *iv, size_t ivlen,
-			    char **ivout, size_t * ivoutlen,
+			    char **ivout, size_t *ivoutlen,
 			    const char *in, size_t inlen,
-			    char **out, size_t * outlen)
+			    char **out, size_t *outlen)
 {
   int res;
   int padzerolen = 0;
@@ -399,9 +399,9 @@ _shishi_simplified_decrypt (Shishi * handle,
 			    Shishi_key * key,
 			    int keyusage,
 			    const char *iv, size_t ivlen,
-			    char **ivout, size_t * ivoutlen,
+			    char **ivout, size_t *ivoutlen,
 			    const char *in, size_t inlen,
-			    char **out, size_t * outlen)
+			    char **out, size_t *outlen)
 {
   int res;
 
@@ -462,7 +462,7 @@ _shishi_simplified_checksum (Shishi * handle,
 			     int keyusage,
 			     int cksumtype,
 			     const char *in, size_t inlen,
-			     char **out, size_t * outlen)
+			     char **out, size_t *outlen)
 {
   Shishi_key *checksumkey;
   int cksumlen = shishi_checksum_cksumlen (cksumtype);
@@ -1046,7 +1046,7 @@ shishi_checksum (Shishi * handle,
 		 Shishi_key * key,
 		 int keyusage,
 		 int cksumtype,
-		 const char *in, size_t inlen, char **out, size_t * outlen)
+		 const char *in, size_t inlen, char **out, size_t *outlen)
 {
   Shishi_checksum_function checksum;
   int res;
@@ -1055,7 +1055,7 @@ shishi_checksum (Shishi * handle,
     {
       printf ("checksum (%s, %d, in, out)\n",
 	      shishi_key_name (key), cksumtype);
-      printf ("\t ;; key (%d):\n", shishi_key_length (key));
+      printf ("\t ;; key (%zu):\n", shishi_key_length (key));
       _shishi_hexprint (shishi_key_value (key), shishi_key_length (key));
       printf ("\t ;; in:\n");
       _shishi_escapeprint (in, inlen);
@@ -1117,7 +1117,7 @@ shishi_verify (Shishi * handle,
   if (VERBOSECRYPTO (handle))
     {
       printf ("verify (%s, %d, in, out)\n", shishi_key_name (key), cksumtype);
-      printf ("\t ;; key (%d):\n", shishi_key_length (key));
+      printf ("\t ;; key (%zu):\n", shishi_key_length (key));
       _shishi_hexprint (shishi_key_value (key), shishi_key_length (key));
       printf ("\t ;; data:\n");
       _shishi_escapeprint (in, inlen);
@@ -1186,9 +1186,9 @@ shishi_encrypt_ivupdate_etype (Shishi * handle,
 			       int keyusage,
 			       int32_t etype,
 			       const char *iv, size_t ivlen,
-			       char **ivout, size_t * ivoutlen,
+			       char **ivout, size_t *ivoutlen,
 			       const char *in, size_t inlen,
-			       char **out, size_t * outlen)
+			       char **out, size_t *outlen)
 {
   Shishi_encrypt_function enc;
   int res;
@@ -1197,14 +1197,14 @@ shishi_encrypt_ivupdate_etype (Shishi * handle,
     {
       printf ("encrypt (type=%s, usage=%d, key, in)\n",
 	      shishi_key_name (key), keyusage);
-      printf ("\t ;; key (%d):\n", shishi_key_length (key));
+      printf ("\t ;; key (%zu):\n", shishi_key_length (key));
       _shishi_hexprint (shishi_key_value (key), shishi_key_length (key));
-      printf ("\t ;; in (%d):\n", inlen);
+      printf ("\t ;; in (%zu):\n", inlen);
       _shishi_escapeprint (in, inlen);
       _shishi_hexprint (in, inlen);
       if (iv)
 	{
-	  printf ("\t ;; iv (%d):\n", ivlen);
+	  printf ("\t ;; iv (%zu):\n", ivlen);
 	  _shishi_escapeprint (iv, ivlen);
 	  _shishi_hexprint (iv, ivlen);
 	}
@@ -1281,7 +1281,7 @@ shishi_encrypt_iv_etype (Shishi * handle,
 			 int32_t etype,
 			 const char *iv, size_t ivlen,
 			 const char *in, size_t inlen,
-			 char **out, size_t * outlen)
+			 char **out, size_t *outlen)
 {
   return shishi_encrypt_ivupdate_etype (handle, key, keyusage, etype,
 					iv, ivlen, NULL, NULL,
@@ -1323,7 +1323,7 @@ shishi_encrypt_etype (Shishi * handle,
 		      int keyusage,
 		      int32_t etype,
 		      const char *in, size_t inlen,
-		      char **out, size_t * outlen)
+		      char **out, size_t *outlen)
 {
   return shishi_encrypt_ivupdate_etype (handle, key, keyusage,
 					shishi_key_type (key),
@@ -1367,9 +1367,9 @@ shishi_encrypt_ivupdate (Shishi * handle,
 			 Shishi_key * key,
 			 int keyusage,
 			 const char *iv, size_t ivlen,
-			 char **ivout, size_t * ivoutlen,
+			 char **ivout, size_t *ivoutlen,
 			 const char *in, size_t inlen,
-			 char **out, size_t * outlen)
+			 char **out, size_t *outlen)
 {
   return shishi_encrypt_ivupdate_etype (handle, key, keyusage,
 					shishi_key_type (key),
@@ -1411,7 +1411,7 @@ shishi_encrypt_iv (Shishi * handle,
 		   Shishi_key * key,
 		   int keyusage,
 		   const char *iv, size_t ivlen,
-		   const char *in, size_t inlen, char **out, size_t * outlen)
+		   const char *in, size_t inlen, char **out, size_t *outlen)
 {
   return shishi_encrypt_ivupdate_etype (handle, key, keyusage,
 					shishi_key_type (key),
@@ -1450,7 +1450,7 @@ int
 shishi_encrypt (Shishi * handle,
 		Shishi_key * key,
 		int keyusage,
-		char *in, size_t inlen, char **out, size_t * outlen)
+		char *in, size_t inlen, char **out, size_t *outlen)
 {
   return shishi_encrypt_ivupdate_etype (handle, key, keyusage,
 					shishi_key_type (key),
@@ -1496,9 +1496,9 @@ shishi_decrypt_ivupdate_etype (Shishi * handle,
 			       int keyusage,
 			       int32_t etype,
 			       const char *iv, size_t ivlen,
-			       char **ivout, size_t * ivoutlen,
+			       char **ivout, size_t *ivoutlen,
 			       const char *in, size_t inlen,
-			       char **out, size_t * outlen)
+			       char **out, size_t *outlen)
 {
   Shishi_decrypt_function decrypt;
   int res;
@@ -1507,14 +1507,14 @@ shishi_decrypt_ivupdate_etype (Shishi * handle,
     {
       printf ("decrypt (type=%s, usage=%d, key, in, out)\n",
 	      shishi_key_name (key), keyusage);
-      printf ("\t ;; key (%d):\n", shishi_key_length (key));
+      printf ("\t ;; key (%zu):\n", shishi_key_length (key));
       _shishi_hexprint (shishi_key_value (key), shishi_key_length (key));
-      printf ("\t ;; in (%d):\n", inlen);
+      printf ("\t ;; in (%zu):\n", inlen);
       _shishi_escapeprint (in, inlen);
       _shishi_hexprint (in, inlen);
       if (iv)
 	{
-	  printf ("\t ;; iv (%d):\n", ivlen);
+	  printf ("\t ;; iv (%zu):\n", ivlen);
 	  _shishi_escapeprint (iv, ivlen);
 	  _shishi_hexprint (iv, ivlen);
 	}
@@ -1585,7 +1585,7 @@ shishi_decrypt_iv_etype (Shishi * handle,
 			 int32_t etype,
 			 const char *iv, size_t ivlen,
 			 const char *in, size_t inlen,
-			 char **out, size_t * outlen)
+			 char **out, size_t *outlen)
 {
   return shishi_decrypt_ivupdate_etype (handle, key, keyusage, etype,
 					iv, ivlen, NULL, NULL,
@@ -1627,7 +1627,7 @@ shishi_decrypt_etype (Shishi * handle,
 		      int keyusage,
 		      int32_t etype,
 		      const char *in, size_t inlen,
-		      char **out, size_t * outlen)
+		      char **out, size_t *outlen)
 {
   return shishi_decrypt_ivupdate_etype (handle, key, keyusage, etype,
 					NULL, 0, NULL, NULL,
@@ -1670,9 +1670,9 @@ shishi_decrypt_ivupdate (Shishi * handle,
 			 Shishi_key * key,
 			 int keyusage,
 			 const char *iv, size_t ivlen,
-			 char **ivout, size_t * ivoutlen,
+			 char **ivout, size_t *ivoutlen,
 			 const char *in, size_t inlen,
-			 char **out, size_t * outlen)
+			 char **out, size_t *outlen)
 {
   return shishi_decrypt_ivupdate_etype (handle, key, keyusage,
 					shishi_key_type (key),
@@ -1714,7 +1714,7 @@ shishi_decrypt_iv (Shishi * handle,
 		   Shishi_key * key,
 		   int keyusage,
 		   const char *iv, size_t ivlen,
-		   const char *in, size_t inlen, char **out, size_t * outlen)
+		   const char *in, size_t inlen, char **out, size_t *outlen)
 {
   return shishi_decrypt_ivupdate_etype (handle, key, keyusage,
 					shishi_key_type (key),
@@ -1753,7 +1753,7 @@ int
 shishi_decrypt (Shishi * handle,
 		Shishi_key * key,
 		int keyusage,
-		const char *in, size_t inlen, char **out, size_t * outlen)
+		const char *in, size_t inlen, char **out, size_t *outlen)
 {
   return shishi_decrypt_ivupdate_etype (handle, key, keyusage,
 					shishi_key_type (key),
@@ -1913,9 +1913,9 @@ shishi_dr (Shishi * handle,
 
   if (VERBOSECRYPTO (handle))
     {
-      printf ("dr (%s, key, prfconstant, %d)\n",
+      printf ("dr (%s, key, prfconstant, %zu)\n",
 	      shishi_cipher_name (shishi_key_type (key)), derivedrandomlen);
-      printf ("\t ;; key (length %d):\n", shishi_key_length (key));
+      printf ("\t ;; key (length %zu):\n", shishi_key_length (key));
       _shishi_hexprint (shishi_key_value (key), shishi_key_length (key));
       _shishi_binprint (shishi_key_value (key), shishi_key_length (key));
       printf ("\t ;; prfconstant  %s':\n", prfconstant);
@@ -1939,7 +1939,8 @@ shishi_dr (Shishi * handle,
 
   if (VERBOSECRYPTO (handle))
     {
-      printf ("\t ;; possibly nfolded prfconstant (length %d):\n", blocksize);
+      printf ("\t ;; possibly nfolded prfconstant (length %zu):\n",
+	      blocksize);
       _shishi_escapeprint (nfoldprfconstant, blocksize);
       _shishi_hexprint (nfoldprfconstant, blocksize);
       _shishi_binprint (nfoldprfconstant, blocksize);
@@ -1965,7 +1966,7 @@ shishi_dr (Shishi * handle,
 
   if (VERBOSECRYPTO (handle))
     {
-      printf ("\t ;; derived random (length %d):\n", derivedrandomlen);
+      printf ("\t ;; derived random (length %zu):\n", derivedrandomlen);
       _shishi_hexprint (derivedrandom, derivedrandomlen);
       _shishi_binprint (derivedrandom, derivedrandomlen);
     }
@@ -1998,7 +1999,7 @@ shishi_dk (Shishi * handle,
   if (VERBOSECRYPTO (handle))
     {
       printf ("dk (%s, key, prfconstant)\n", shishi_key_name (key));
-      printf ("\t ;; key (length %d):\n", shishi_key_length (key));
+      printf ("\t ;; key (length %zu):\n", shishi_key_length (key));
       _shishi_hexprint (shishi_key_value (key), shishi_key_length (key));
       _shishi_binprint (shishi_key_value (key), shishi_key_length (key));
       printf ("\t ;; prfconstant:\n");
