@@ -1,5 +1,5 @@
 /* crypto.h --- Crypto prototypes.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -21,9 +21,9 @@
  */
 
 #ifndef _CRYPTO_H
-#define _CRYPTO_H
+# define _CRYPTO_H
 
-#define SHISHI_DK_CONSTANT "\x6b\x65\x72\x62\x65\x72\x6f\x73"
+# define SHISHI_DK_CONSTANT "\x6b\x65\x72\x62\x65\x72\x6f\x73"
 
 int
 _shishi_simplified_derivekey (Shishi * handle,
@@ -36,30 +36,30 @@ _shishi_simplified_checksum (Shishi * handle,
 			     int keyusage,
 			     int cksumtype,
 			     const char *in, size_t inlen,
-			     char **out, size_t * outlen);
+			     char **out, size_t *outlen);
 int
 _shishi_simplified_dencrypt (Shishi * handle,
 			     Shishi_key * key,
 			     const char *iv, size_t ivlen,
-			     char **ivout, size_t * ivoutlen,
+			     char **ivout, size_t *ivoutlen,
 			     const char *in, size_t inlen,
-			     char **out, size_t * outlen, int decryptp);
+			     char **out, size_t *outlen, int decryptp);
 int
 _shishi_simplified_encrypt (Shishi * handle,
 			    Shishi_key * key,
 			    int keyusage,
 			    const char *iv, size_t ivlen,
-			    char **ivout, size_t * ivoutlen,
+			    char **ivout, size_t *ivoutlen,
 			    const char *in, size_t inlen,
-			    char **out, size_t * outlen);
+			    char **out, size_t *outlen);
 int
 _shishi_simplified_decrypt (Shishi * handle,
 			    Shishi_key * key,
 			    int keyusage,
 			    const char *iv, size_t ivlen,
-			    char **ivout, size_t * ivoutlen,
+			    char **ivout, size_t *ivoutlen,
 			    const char *in, size_t inlen,
-			    char **out, size_t * outlen);
+			    char **out, size_t *outlen);
 
 typedef enum
 {
@@ -86,24 +86,24 @@ typedef int (*Shishi_encrypt_function) (Shishi * handle,
 					Shishi_key * key,
 					int keyusage,
 					const char *iv, size_t ivlen,
-					char **ivout, size_t * ivoutlen,
+					char **ivout, size_t *ivoutlen,
 					const char *in, size_t inlen,
-					char **out, size_t * outlen);
+					char **out, size_t *outlen);
 
 typedef int (*Shishi_decrypt_function) (Shishi * handle,
 					Shishi_key * key,
 					int keyusage,
 					const char *iv, size_t ivlen,
-					char **ivout, size_t * ivoutlen,
+					char **ivout, size_t *ivoutlen,
 					const char *in, size_t inlen,
-					char **out, size_t * outlen);
+					char **out, size_t *outlen);
 
 typedef int (*Shishi_checksum_function) (Shishi * handle,
 					 Shishi_key * key,
 					 int keyusage,
 					 int cksumtype,
 					 const char *in, size_t inlen,
-					 char **out, size_t * outlen);
+					 char **out, size_t *outlen);
 
 typedef int (*Shishi_verify_function) (Shishi * handle,
 				       Shishi_key * key,
@@ -120,7 +120,7 @@ struct cipherinfo
   size_t confoundersize;
   size_t keylen;
   size_t randomlen;
-  uint32_t defaultcksumtype;
+  int32_t defaultcksumtype;
   Shishi_random_to_key_function random2key;
   Shishi_string_to_key_function string2key;
   Shishi_encrypt_function encrypt;
