@@ -1,5 +1,5 @@
 /* diskio.c --- Read and write data structures from disk.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -305,7 +305,7 @@ _shishi_ticket_input (Shishi * handle,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -362,7 +362,7 @@ _shishi_enckdcreppart_input (Shishi * handle,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -441,7 +441,7 @@ _shishi_kdcreq_input (Shishi * handle, FILE * fh, Shishi_asn1 * asreq,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -504,7 +504,7 @@ _shishi_kdcrep_input (Shishi * handle, FILE * fh, Shishi_asn1 * asrep,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -566,7 +566,7 @@ _shishi_apreq_input (Shishi * handle, FILE * fh, Shishi_asn1 * apreq,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -615,7 +615,7 @@ _shishi_aprep_input (Shishi * handle, FILE * fh, Shishi_asn1 * aprep,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -666,7 +666,7 @@ _shishi_encapreppart_input (Shishi * handle, FILE * fh,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -716,7 +716,7 @@ _shishi_authenticator_input (Shishi * handle,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -766,7 +766,7 @@ _shishi_krberror_input (Shishi * handle,
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -815,7 +815,7 @@ _shishi_safe_input (Shishi * handle, FILE * fh, Shishi_asn1 * safe, int type)
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -864,7 +864,7 @@ _shishi_priv_input (Shishi * handle, FILE * fh, Shishi_asn1 * priv, int type)
       if (derlen <= 0 || !feof (fh) || ferror (fh))
 	{
 	  shishi_error_printf (handle,
-			       "Error reading from file (got %ld bytes)...",
+			       "Error reading from file (got %zu bytes)...",
 			       derlen);
 	  return !SHISHI_OK;
 	}
@@ -903,12 +903,12 @@ shishi_key_parse (Shishi * handle, FILE * fh, Shishi_key ** key)
       line[sizeof (line) - 1] = '\0';
       if (!*line || line[strlen (line) - 1] != '\n')
 	{
-	  fprintf (stderr, "input line %u too long or missing LF\n", lno);
+	  fprintf (stderr, "input line %d too long or missing LF\n", lno);
 	  continue;
 	}
       line[strlen (line) - 1] = '\0';
       if (VERBOSENOISE (handle))
-	printf ("line %d read %ld bytes: %s\n", lno, strlen (line), line);
+	printf ("line %d read %zu bytes: %s\n", lno, strlen (line), line);
 
       if (!in_key)
 	{
@@ -960,6 +960,15 @@ shishi_key_parse (Shishi * handle, FILE * fh, Shishi_key ** key)
 	    {
 	      shishi_key_principal_set (lkey, line + strlen ("Principal: "));
 	    }
+	  else if (strncmp (line, "Timestamp: ", strlen ("Timestamp: ")) == 0)
+	    {
+	      time_t timestamp;
+
+	      timestamp = shishi_generalize_ctime (handle,
+						   line +
+						   strlen ("Timestamp: "));
+	      shishi_key_timestamp_set (lkey, timestamp);
+	    }
 	}
     }
 
@@ -973,23 +982,25 @@ shishi_key_parse (Shishi * handle, FILE * fh, Shishi_key ** key)
 
 /**
  * shishi_key_print:
- * @handle: shishi handle as allocated by shishi_init().
- * @fh: file handle opened for writing.
- * @key: key to print.
+ * @handle: Shishi handle as allocated by shishi_init().
+ * @fh: File handle open for writing.
+ * @key: Key to print.
  *
- * Print an ASCII representation of a key structure to file
- * descriptor.  Example output:
+ * Prints an ASCII representation of a key structure @key
+ * to the file descriptor @fh.  Example output:
  *
  * -----BEGIN SHISHI KEY-----
  * Keytype: 18 (aes256-cts-hmac-sha1-96)
  * Principal: host/latte.josefsson.org
  * Realm: JOSEFSSON.ORG
  * Key-Version-Number: 1
+ * Timestamp: 20130420150337Z
  *
  * P1QdeW/oSiag/bTyVEBAY2msiGSTmgLXlopuCKoppDs=
  * -----END SHISHI KEY-----
  *
- * Return value: Returns SHISHI_OK iff successful.
+ * Return value: Returns %SHISHI_OK if successful.
+ *   The only failure is %SHISHI_MALLOC_ERROR.
  **/
 int
 shishi_key_print (Shishi * handle, FILE * fh, const Shishi_key * key)
@@ -1012,7 +1023,11 @@ shishi_key_print (Shishi * handle, FILE * fh, const Shishi_key * key)
   if (shishi_key_realm (key))
     fprintf (fh, "Realm: %s\n", shishi_key_realm (key));
   if (shishi_key_version (key) != UINT32_MAX)
-    fprintf (fh, "Key-Version-Number: %d\n", shishi_key_version (key));
+    fprintf (fh, "Key-Version-Number: %" PRIu32 "\n",
+	     shishi_key_version (key));
+  if (shishi_key_timestamp (key))
+    fprintf (fh, "Timestamp: %s\n",
+	     shishi_generalize_time (handle, shishi_key_timestamp (key)));
   fprintf (fh, "\n");
 
   for (i = 0; i < strlen (b64key); i++)
@@ -1042,15 +1057,16 @@ shishi_key_print (Shishi * handle, FILE * fh, const Shishi_key * key)
 
 /**
  * shishi_key_to_file:
- * @handle: shishi handle as allocated by shishi_init().
- * @filename: filename to append key to.
- * @key: key to print.
+ * @handle: Shishi handle as allocated by shishi_init().
+ * @filename: Name of file, to which the key text is appended.
+ * @key: Key to print.
  *
- * Print an ASCII representation of a key structure to a file.  The
- * file is appended to if it exists.  See shishi_key_print() for
- * format of output.
+ * Prints an ASCII representation of a key structure @key
+ * to the file @filename.  The text is appended if the file
+ * exists.  See shishi_key_print() for an example of output text.
  *
- * Return value: Returns SHISHI_OK iff successful.
+ * Return value: Returns %SHISHI_OK if successful.
+ *   Failures are due to I/O issues, or to allocation.
  **/
 int
 shishi_key_to_file (Shishi * handle, const char *filename, Shishi_key * key)
