@@ -1,5 +1,5 @@
 /* internal.h --- Internal header file for Shishi.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -21,92 +21,88 @@
  */
 
 #ifndef _INTERNAL_H
-#define _INTERNAL_H
+# define _INTERNAL_H
 
-#if HAVE_CONFIG_H
-#include "config.h"
-#endif
+# if HAVE_CONFIG_H
+#  include "config.h"
+# endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <ctype.h>
-#include <string.h>
-#include <stdbool.h>
-#include <stdint.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/select.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <sys/time.h>
-#include <time.h>
-#include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <stdarg.h>
+# include <ctype.h>
+# include <string.h>
+# include <stdbool.h>
+# include <stdint.h>
+# include <sys/types.h>
+# include <sys/socket.h>
+# include <sys/select.h>
+# include <sys/stat.h>
+# include <unistd.h>
+# include <sys/time.h>
+# include <time.h>
+# include <signal.h>
+# include <inttypes.h>
+# include <netdb.h>
 
-#ifdef HAVE_SYS_IOCTL_H
-#include <sys/ioctl.h>
-#endif
-
-#include <netdb.h>
-
-#if !HAVE_DECL_H_ERRNO
+# if !HAVE_DECL_H_ERRNO
 /*extern int h_errno;*/
-#endif
+# endif
 
-#include <fcntl.h>
+# include <fcntl.h>
 
-#include <errno.h>
+# include <errno.h>
 
-#include <netinet/in.h>
-#ifdef HAVE_NETINET_IN6_H
-#include <netinet/in6.h>
-#endif
-#include <arpa/inet.h>
+# include <netinet/in.h>
+# ifdef HAVE_NETINET_IN6_H
+#  include <netinet/in6.h>
+# endif
+# include <arpa/inet.h>
 
-#ifdef HAVE_SYSLOG_H
-#include <syslog.h>
-#endif
+# ifdef HAVE_SYSLOG_H
+#  include <syslog.h>
+# endif
 
-#include "gettext.h"
+# include "gettext.h"
 
-#include "xvasprintf.h"
-#include "base64.h"
-#include "parse-datetime.h"
-#include "read-file.h"
-#include "timespec.h"
-#include "xalloc.h"
-#include "xgethostname.h"
-#include "xgetdomainname.h"
-#include "xstrndup.h"
+# include "xvasprintf.h"
+# include "base64.h"
+# include "parse-datetime.h"
+# include "read-file.h"
+# include "timespec.h"
+# include "xalloc.h"
+# include "xgethostname.h"
+# include "xgetdomainname.h"
+# include "xstrndup.h"
 
-#include "shishi.h"
+# include "shishi.h"
 
-#define _(String) dgettext (PACKAGE, String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop (String)
+# define _(String) dgettext (PACKAGE, String)
+# define gettext_noop(String) String
+# define N_(String) gettext_noop (String)
 
-#define MAX_KEY_LEN 32
-#define MAX_RANDOM_LEN 32
-#define MAX_HASH_LEN 32
-#define MAX_CKSUM_LEN 32
+# define MAX_KEY_LEN 32
+# define MAX_RANDOM_LEN 32
+# define MAX_HASH_LEN 32
+# define MAX_CKSUM_LEN 32
 
-#define SHISHI_VERBOSE_NOISE		(1<<1)
-#define SHISHI_VERBOSE_ASN1		(1<<2)
-#define SHISHI_VERBOSE_CRYPTO		(1<<3)
-#define SHISHI_VERBOSE_CRYPTO_NOISE	(1<<4)
+# define SHISHI_VERBOSE_NOISE		(1<<1)
+# define SHISHI_VERBOSE_ASN1		(1<<2)
+# define SHISHI_VERBOSE_CRYPTO		(1<<3)
+# define SHISHI_VERBOSE_CRYPTO_NOISE	(1<<4)
 
-#define KRBTGT "krbtgt"
-#define PRINCIPAL_DELIMITER "/"
+# define KRBTGT "krbtgt"
+# define PRINCIPAL_DELIMITER "/"
 
-#define VERBOSENOISE(h) (h->verbose & SHISHI_VERBOSE_NOISE)
-#define VERBOSEASN1(h) (h->verbose & SHISHI_VERBOSE_ASN1)
-#define VERBOSECRYPTO(h) (h->verbose & SHISHI_VERBOSE_CRYPTO)
-#define VERBOSECRYPTONOISE(h) (h->verbose & SHISHI_VERBOSE_CRYPTO_NOISE)
-#define VERBOSES (SHISHI_VERBOSE_ASN1 |		\
+# define VERBOSENOISE(h) (h->verbose & SHISHI_VERBOSE_NOISE)
+# define VERBOSEASN1(h) (h->verbose & SHISHI_VERBOSE_ASN1)
+# define VERBOSECRYPTO(h) (h->verbose & SHISHI_VERBOSE_CRYPTO)
+# define VERBOSECRYPTONOISE(h) (h->verbose & SHISHI_VERBOSE_CRYPTO_NOISE)
+# define VERBOSES (SHISHI_VERBOSE_ASN1 |		\
 		  SHISHI_VERBOSE_CRYPTO |	\
 		  SHISHI_VERBOSE_NOISE |	\
 		  SHISHI_VERBOSE_CRYPTO_NOISE)
-#define VERBOSE(h) (h->verbose & ~VERBOSES)
+# define VERBOSE(h) (h->verbose & ~VERBOSES)
 
 /* Transports */
 enum
@@ -164,7 +160,7 @@ struct Shishi
   shishi_prompt_password_func prompt_passwd;
 };
 
-#define TICKETLIFE (60*60*8)	/* Work day */
-#define RENEWLIFE (60*60*24*7)	/* Week */
+# define TICKETLIFE (60*60*8)	/* Work day */
+# define RENEWLIFE (60*60*24*7)	/* Week */
 
 #endif /* _INTERNAL_H */
