@@ -1,5 +1,5 @@
 /* kdcreq.c --- Key distribution (AS/TGS) request functions.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -407,7 +407,7 @@ shishi_kdcreq_set_cname (Shishi * handle,
  **/
 int
 shishi_kdcreq_client (Shishi * handle, Shishi_asn1 kdcreq,
-		      char **client, size_t * clientlen)
+		      char **client, size_t *clientlen)
 {
   return shishi_principal_name (handle, kdcreq, "req-body.cname",
 				client, clientlen);
@@ -431,8 +431,7 @@ shishi_kdcreq_client (Shishi * handle, Shishi_asn1 kdcreq,
  **/
 int
 shishi_asreq_clientrealm (Shishi * handle,
-			  Shishi_asn1 asreq,
-			  char **client, size_t * clientlen)
+			  Shishi_asn1 asreq, char **client, size_t *clientlen)
 {
   return shishi_principal_name_realm (handle,
 				      asreq, "req-body.cname",
@@ -458,7 +457,7 @@ shishi_asreq_clientrealm (Shishi * handle,
  **/
 int
 shishi_kdcreq_realm (Shishi * handle, Shishi_asn1 kdcreq,
-		     char **realm, size_t * realmlen)
+		     char **realm, size_t *realmlen)
 {
   return shishi_asn1_read_optional (handle, kdcreq, "req-body.realm",
 				    realm, realmlen);
@@ -466,7 +465,7 @@ shishi_kdcreq_realm (Shishi * handle, Shishi_asn1 kdcreq,
 
 int
 shishi_kdcreq_realm_get (Shishi * handle, Shishi_asn1 kdcreq,
-			 char **realm, size_t * realmlen)
+			 char **realm, size_t *realmlen)
 {
   return shishi_asn1_read_optional (handle, kdcreq, "req-body.realm",
 				    realm, realmlen);
@@ -513,7 +512,7 @@ shishi_kdcreq_set_realm (Shishi * handle, Shishi_asn1 kdcreq,
  **/
 int
 shishi_kdcreq_server (Shishi * handle, Shishi_asn1 kdcreq,
-		      char **server, size_t * serverlen)
+		      char **server, size_t *serverlen)
 {
   return shishi_principal_name (handle, kdcreq, "req-body.sname",
 				server, serverlen);
@@ -578,38 +577,38 @@ shishi_kdcreq_set_realmserver (Shishi * handle,
 
 /**
  * shishi_kdcreq_till:
- * @handle: Shishi library handle create by shishi_init().
- * @kdcreq: KDC-REQ variable to get client name from.
- * @till: pointer to newly allocated zero terminated string containing
- *   "till" field with generalized time.  May be %NULL (to only
- *   populate @realmlen).
- * @tilllen: pointer to length of @till on output, excluding
- *   terminating zero.  May be %NULL (to only populate @tilllen).
+ * @handle: Shishi library handle created by shishi_init().
+ * @kdcreq: KDC-REQ variable to get endtime from.
+ * @till: pointer to newly allocated null terminated string containing
+ *   "till" field with generalized time.  May be passed as %NULL
+ *   to only populate @tilllen.
+ * @tilllen: pointer to length of @till for output, excluding the
+ *   terminating null.  Set to %NULL, only @till is populated.
  *
- * Get "till" field (i.e. "endtime") in KDC-REQ, as zero-terminated
- * string.  The string is typically 15 characters long.  The string is
- * allocated by this function, and it is the responsibility of the
- * caller to deallocate it.  Note that the output length @realmlen
+ * Get "till" field, i.e., "endtime", in KDC-REQ as a null-terminated
+ * string.  The string is typically 15 characters long and is
+ * allocated by this function. It is the responsibility of the
+ * caller to deallocate it.  Note that the output length @tilllen
  * does not include the terminating zero.
  *
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
 shishi_kdcreq_till (Shishi * handle, Shishi_asn1 kdcreq,
-		    char **till, size_t * tilllen)
+		    char **till, size_t *tilllen)
 {
   return shishi_asn1_read (handle, kdcreq, "req-body.till", till, tilllen);
 }
 
 /**
  * shishi_kdcreq_tillc:
- * @handle: Shishi library handle create by shishi_init().
- * @kdcreq: KDC-REQ variable to get till field from.
+ * @handle: Shishi library handle created by shishi_init().
+ * @kdcreq: KDC-REQ variable to get "till" field from.
  *
  * Extract C time corresponding to the "till" field.
  *
- * Return value: Returns C time interpretation of the "till" field in
- * KDC-REQ.
+ * Return value: Returns the C time interpretation of the "till"
+ * field in KDC-REQ.
  **/
 time_t
 shishi_kdcreq_tillc (Shishi * handle, Shishi_asn1 kdcreq)
@@ -1125,7 +1124,7 @@ int
 shishi_kdcreq_get_padata (Shishi * handle,
 			  Shishi_asn1 kdcreq,
 			  Shishi_padata_type padatatype,
-			  char **out, size_t * outlen)
+			  char **out, size_t *outlen)
 {
   char *format;
   int res;
@@ -1142,7 +1141,7 @@ shishi_kdcreq_get_padata (Shishi * handle,
     {
       int32_t patype;
 
-      asprintf (&format, "padata.?%d.padata-type", i);
+      asprintf (&format, "padata.?%zu.padata-type", i);
       res = shishi_asn1_read_int32 (handle, kdcreq, format, &patype);
       free (format);
       if (res != SHISHI_OK)
@@ -1150,7 +1149,7 @@ shishi_kdcreq_get_padata (Shishi * handle,
 
       if (patype == (int32_t) padatatype)
 	{
-	  asprintf (&format, "padata.?%d.padata-value", i);
+	  asprintf (&format, "padata.?%zu.padata-value", i);
 	  res = shishi_asn1_read (handle, kdcreq, format, out, outlen);
 	  free (format);
 	  if (res != SHISHI_OK)
@@ -1234,13 +1233,13 @@ shishi_kdcreq_add_padata (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  asprintf (&format, "padata.?%d.padata-value", i);
+  asprintf (&format, "padata.?%zu.padata-value", i);
   res = shishi_asn1_write (handle, kdcreq, format, data, datalen);
   free (format);
   if (res != SHISHI_OK)
     return res;
 
-  asprintf (&format, "padata.?%d.padata-type", i);
+  asprintf (&format, "padata.?%zu.padata-type", i);
   res = shishi_asn1_write_uint32 (handle, kdcreq, format, padatatype);
   free (format);
   if (res != SHISHI_OK)
