@@ -4,7 +4,7 @@
 
 #include <libtasn1.h>
 
-const ASN1_ARRAY_TYPE shishi_asn1_tab[] = {
+const asn1_static_node shishi_asn1_tab[] = {
   { "KerberosV5Spec2", 536872976, NULL },
   { NULL, 1610612748, NULL },
   { "iso", 1073741825, "1"},
@@ -23,10 +23,8 @@ const ASN1_ARRAY_TYPE shishi_asn1_tab[] = {
   { "security", 1073741825, "5"},
   { "kerberosV5", 1, "2"},
   { "Int32", 1073741827, NULL },
-  { "UInt32", 1611137027, NULL },
-  { "0", 10, "4294967295"},
-  { "Microseconds", 1611137027, NULL },
-  { "0", 10, "999999"},
+  { "UInt32", 1073741827, NULL },
+  { "Microseconds", 1073741827, NULL },
   { "KerberosString", 1073741851, NULL },
   { "Realm", 1073741826, "KerberosString"},
   { "PrincipalName", 1610612741, NULL },
@@ -35,7 +33,7 @@ const ASN1_ARRAY_TYPE shishi_asn1_tab[] = {
   { "name-string", 536879115, NULL },
   { NULL, 1073743880, "1"},
   { NULL, 2, "KerberosString"},
-  { "KerberosTime", 1082130449, NULL },
+  { "KerberosTime", 1073741861, NULL },
   { "HostAddress", 1610612741, NULL },
   { "addr-type", 1610620930, "Int32"},
   { NULL, 2056, "0"},
@@ -385,7 +383,6 @@ const ASN1_ARRAY_TYPE shishi_asn1_tab[] = {
   { "METHOD-DATA", 1610612747, NULL },
   { NULL, 2, "PA-DATA"},
   { "TYPED-DATA", 1612709899, NULL },
-  { "MAX", 1074266122, "1"},
   { NULL, 536870917, NULL },
   { "data-type", 1610620930, "Int32"},
   { NULL, 2056, "0"},
@@ -412,7 +409,6 @@ const ASN1_ARRAY_TYPE shishi_asn1_tab[] = {
   { "s2kparams", 536895495, NULL },
   { NULL, 2056, "2"},
   { "ETYPE-INFO2", 1612709899, NULL },
-  { "MAX", 1074266122, "1"},
   { NULL, 2, "ETYPE-INFO2-ENTRY"},
   { "AD-IF-RELEVANT", 1073741826, "AuthorizationData"},
   { "AD-KDCIssued", 1610612741, NULL },
