@@ -1,5 +1,5 @@
 /* krberror.c --- Functions related to KRB-ERROR packet.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -392,7 +392,7 @@ shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror)
  **/
 int
 shishi_krberror_der (Shishi * handle,
-		     Shishi_asn1 krberror, char **out, size_t * outlen)
+		     Shishi_asn1 krberror, char **out, size_t *outlen)
 {
   int rc;
 
@@ -420,7 +420,7 @@ shishi_krberror_der (Shishi * handle,
  **/
 int
 shishi_krberror_crealm (Shishi * handle,
-			Shishi_asn1 krberror, char **realm, size_t * realmlen)
+			Shishi_asn1 krberror, char **realm, size_t *realmlen)
 {
   return shishi_asn1_read (handle, krberror, "crealm", realm, realmlen);
 }
@@ -485,7 +485,7 @@ shishi_krberror_set_crealm (Shishi * handle,
 int
 shishi_krberror_client (Shishi * handle,
 			Shishi_asn1 krberror,
-			char **client, size_t * clientlen)
+			char **client, size_t *clientlen)
 {
   int rc;
 
@@ -580,7 +580,7 @@ shishi_krberror_client_set (Shishi * handle,
  **/
 int
 shishi_krberror_realm (Shishi * handle,
-		       Shishi_asn1 krberror, char **realm, size_t * realmlen)
+		       Shishi_asn1 krberror, char **realm, size_t *realmlen)
 {
   return shishi_asn1_read (handle, krberror, "realm", realm, realmlen);
 }
@@ -624,7 +624,7 @@ shishi_krberror_set_realm (Shishi * handle,
 int
 shishi_krberror_server (Shishi * handle,
 			Shishi_asn1 krberror,
-			char **server, size_t * serverlen)
+			char **server, size_t *serverlen)
 {
   int rc;
 
@@ -1004,7 +1004,7 @@ shishi_krberror_errorcode_set (Shishi * handle,
  **/
 int
 shishi_krberror_etext (Shishi * handle, Shishi_asn1 krberror,
-		       char **etext, size_t * etextlen)
+		       char **etext, size_t *etextlen)
 {
   return shishi_asn1_read (handle, krberror, "e-text", etext, etextlen);
 }
@@ -1066,7 +1066,7 @@ shishi_krberror_remove_etext (Shishi * handle, Shishi_asn1 krberror)
  **/
 int
 shishi_krberror_edata (Shishi * handle, Shishi_asn1 krberror,
-		       char **edata, size_t * edatalen)
+		       char **edata, size_t *edatalen)
 {
   return shishi_asn1_read (handle, krberror, "e-data", edata, edatalen);
 }
@@ -1222,7 +1222,7 @@ shishi_krberror_pretty_print (Shishi * handle, FILE * fh,
 
 	      for (i = 1; i <= n; i++)
 		{
-		  char *format = xasprintf ("?%ld.padata-type", i);
+		  char *format = xasprintf ("?%zu.padata-type", i);
 		  int32_t padatatype;
 
 		  if (i > 1)
