@@ -1,5 +1,5 @@
 /* password.c --- Get passwords from user.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -124,9 +124,9 @@ shishi_prompt_password (Shishi * handle, char **s, const char *format, ...)
   if (VERBOSENOISE (handle))
     {
       size_t i;
-      printf ("Read password (length %d): ", strlen (*s));
+      printf ("Read password (length %zu): ", strlen (*s));
       for (i = 0; i < strlen (*s); i++)
-	printf ("%02x ", (*s)[i] & 0xFF);
+	printf ("%02x ", (unsigned) (*s)[i] & 0xFF);
       printf ("\n");
     }
 
@@ -151,11 +151,11 @@ shishi_prompt_password (Shishi * handle, char **s, const char *format, ...)
       if (VERBOSENOISE (handle))
 	{
 	  size_t i;
-	  printf ("Password converted to %s (length %d): ",
+	  printf ("Password converted to %s (length %zu): ",
 		  strcasecmp (handle->stringprocess, "stringprep") == 0 ?
 		  "UTF-8" : handle->stringprocess, strlen (*s));
 	  for (i = 0; i < strlen (*s); i++)
-	    printf ("%02x ", (*s)[i] & 0xFF);
+	    printf ("%02x ", (unsigned) (*s)[i] & 0xFF);
 	  printf ("\n");
 	}
 
@@ -175,9 +175,9 @@ shishi_prompt_password (Shishi * handle, char **s, const char *format, ...)
 	  if (VERBOSENOISE (handle))
 	    {
 	      size_t i;
-	      printf ("Stringprep'ed password (length %d): ", strlen (*s));
+	      printf ("Stringprep'ed password (length %zu): ", strlen (*s));
 	      for (i = 0; i < strlen (*s); i++)
-		printf ("%02x ", (*s)[i] & 0xFF);
+		printf ("%02x ", (unsigned) (*s)[i] & 0xFF);
 	      printf ("\n");
 	    }
 
