@@ -1,5 +1,5 @@
 /* principal.c --- Get and set default principal.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -191,7 +191,7 @@ shishi_parse_name (Shishi * handle, const char *name,
 int
 shishi_principal_name (Shishi * handle,
 		       Shishi_asn1 namenode,
-		       const char *namefield, char **out, size_t * outlen)
+		       const char *namefield, char **out, size_t *outlen)
 {
   char *format;
   size_t i, j, n;
@@ -211,7 +211,7 @@ shishi_principal_name (Shishi * handle,
       size_t tmplen;
       size_t safetmplen;
 
-      asprintf (&format, "%s.name-string.?%ld", namefield, i);
+      asprintf (&format, "%s.name-string.?%zu", namefield, i);
       res = shishi_asn1_read (handle, namenode, format, &tmp, &tmplen);
       free (format);
       if (res != SHISHI_OK)
@@ -278,7 +278,7 @@ shishi_principal_name_realm (Shishi * handle,
 			     const char *namefield,
 			     Shishi_asn1 realmnode,
 			     const char *realmfield,
-			     char **out, size_t * outlen)
+			     char **out, size_t *outlen)
 {
   char *tmp;
   size_t tmplen;
