@@ -1,5 +1,5 @@
 /* safe.c --- Application data integrity protection.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -193,7 +193,7 @@ shishi_safe_safe_set (Shishi_safe * safe, Shishi_asn1 asn1safe)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_safe_safe_der (Shishi_safe * safe, char **out, size_t * outlen)
+shishi_safe_safe_der (Shishi_safe * safe, char **out, size_t *outlen)
 {
   int rc;
 
@@ -406,7 +406,7 @@ shishi_safe_from_file (Shishi * handle, Shishi_asn1 * safe,
 int
 shishi_safe_cksum (Shishi * handle,
 		   Shishi_asn1 safe,
-		   int32_t * cksumtype, char **cksum, size_t * cksumlen)
+		   int32_t * cksumtype, char **cksum, size_t *cksumlen)
 {
   int res;
 
@@ -469,8 +469,7 @@ shishi_safe_set_cksum (Shishi * handle,
  **/
 int
 shishi_safe_user_data (Shishi * handle,
-		       Shishi_asn1 safe, char **userdata,
-		       size_t * userdatalen)
+		       Shishi_asn1 safe, char **userdata, size_t *userdatalen)
 {
   int res;
 
