@@ -1,5 +1,5 @@
 /* shishi.h --- Header file for Shishi library.                       -*- c -*-
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -21,27 +21,35 @@
  */
 
 #ifndef SHISHI_H
-#define SHISHI_H
+# define SHISHI_H
 
-#include <stddef.h>		/* size_t */
-#include <stdio.h>		/* FILE */
-#include <stdarg.h>		/* va_list */
-#include <time.h>		/* time_t */
-#include <shishi-int.h>		/* uint32_t */
+/**
+ * SECTION:shishi
+ * @title: shishi.h
+ * @short_description: main library interfaces
+ *
+ * The main library interfaces are declared in shishi.h.
+ */
 
-#define SHISHI_VERSION "1.0.2"
+# include <stddef.h>		/* size_t */
+# include <stdio.h>		/* FILE */
+# include <stdarg.h>		/* va_list */
+# include <time.h>		/* time_t */
+# include <stdint.h>		/* uint32_t */
+
+# include <shishi-version.h>	/* SHISHI_VERSION etc */
 
 # ifdef __cplusplus
 extern "C"
 {
 # endif
 
-#ifndef __attribute__
+# ifndef __attribute__
 /* This feature is available in gcc versions 2.5 and later.  */
-# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
-#  define __attribute__(Spec)	/* empty */
+#  if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
+#   define __attribute__(Spec)	/* empty */
+#  endif
 # endif
-#endif
 
 /* Error codes */
   typedef enum
@@ -213,11 +221,12 @@ extern "C"
     SHISHI_KDCOPTIONS_UNUSED9 = 0x200,	/* bit 9 */
     SHISHI_KDCOPTIONS_UNUSED10 = 0x400,	/* bit 10 */
     SHISHI_KDCOPTIONS_UNUSED11 = 0x800	/* bit 11 */
-#define SHISHI_KDCOPTIONS_DISABLE_TRANSITED_CHECK 0x4000000	/* bit 26 */
-#define SHISHI_KDCOPTIONS_RENEWABLE_OK		  0x8000000	/* bit 27 */
-#define SHISHI_KDCOPTIONS_ENC_TKT_IN_SKEY	  0x10000000	/* bit 28 */
-#define SHISHI_KDCOPTIONS_RENEW			  0x40000000	/* bit 30 */
-#define SHISHI_KDCOPTIONS_VALIDATE		  0x80000000	/* bit 31 */
+# define SHISHI_KDCOPTIONS_DISABLE_TRANSITED_CHECK 0x4000000	/* bit 26 */
+# define SHISHI_KDCOPTIONS_RENEWABLE_OK		  0x8000000	/* bit 27 */
+# define SHISHI_KDCOPTIONS_ENC_TKT_IN_SKEY	  0x10000000	/* bit 28 */
+# define SHISHI_KDCOPTIONS_RENEW			  0x40000000
+      /* bit 30 */
+# define SHISHI_KDCOPTIONS_VALIDATE		  0x80000000	/* bit 31 */
   }
   Shishi_KDCOptions;
 
@@ -562,6 +571,8 @@ extern "C"
   }
   Shishi_tkts_hintflags;
 
+  /* *INDENT-OFF* */
+
   struct Shishi_tkts_hint
   {
     int startpos;
@@ -582,13 +593,7 @@ extern "C"
     size_t preauthsaltlen;
     char *preauths2kparams;
     size_t preauths2kparamslen;
-  };
-  typedef struct Shishi_tkts_hint Shishi_tkts_hint;
-
-/* resolv.c */
-#define SHISHI_DNS_IN 1
-#define SHISHI_DNS_TXT 16
-#define SHISHI_DNS_SRV 33
+};
 
   struct Shishi_dns_st
   {
@@ -599,8 +604,7 @@ extern "C"
     uint32_t ttl;
 
     void *rr;
-  };
-  typedef struct Shishi_dns_st *Shishi_dns;
+};
 
   struct Shishi_dns_srv_st
   {
@@ -609,7 +613,17 @@ extern "C"
     uint16_t port;
 
     char name[256];
-  };
+};
+
+  /* *INDENT-ON* */
+
+  typedef struct Shishi_tkts_hint Shishi_tkts_hint;
+
+  /* resolv.c */
+# define SHISHI_DNS_IN 1
+# define SHISHI_DNS_TXT 16
+# define SHISHI_DNS_SRV 33
+  typedef struct Shishi_dns_st *Shishi_dns;
   typedef struct Shishi_dns_srv_st *Shishi_dns_srv;
 
   typedef struct Shishi Shishi;
@@ -622,15 +636,15 @@ extern "C"
   typedef struct Shishi_keys Shishi_keys;
   typedef struct Shishi_safe Shishi_safe;
   typedef struct Shishi_priv Shishi_priv;
-#ifdef LIBTASN1_H
+# ifdef LIBTASN1_H
   typedef ASN1_TYPE Shishi_asn1;
-#else
+# else
   typedef void *Shishi_asn1;
-#endif
+# endif
   typedef struct Shishi_crypto Shishi_crypto;
 
-#define SHISHI_GENERALIZEDTIME_LENGTH 15
-#define SHISHI_GENERALIZEDTIMEZ_LENGTH (SHISHI_GENERALIZEDTIME_LENGTH + 1)
+# define SHISHI_GENERALIZEDTIME_LENGTH 15
+# define SHISHI_GENERALIZEDTIMEZ_LENGTH (SHISHI_GENERALIZEDTIME_LENGTH + 1)
 
 /* If non-NULL, call this function when memory is exhausted. */
   extern void (*shishi_alloc_fail_function) (void);
@@ -668,15 +682,15 @@ extern "C"
   extern void shishi_error_clear (Shishi * handle);
   extern void shishi_error_set (Shishi * handle, const char *errstr);
   extern void shishi_error_printf (Shishi * handle, const char *format, ...)
-    __attribute__ ((format (printf, 2, 3)));
+    __attribute__((format (printf, 2, 3)));
   extern int shishi_error_outputtype (Shishi * handle);
   extern void shishi_error_set_outputtype (Shishi * handle, int type);
   extern void shishi_info (Shishi * handle, const char *format, ...)
-    __attribute__ ((format (printf, 2, 3)));
+    __attribute__((format (printf, 2, 3)));
   extern void shishi_warn (Shishi * handle, const char *format, ...)
-    __attribute__ ((format (printf, 2, 3)));
+    __attribute__((format (printf, 2, 3)));
   extern void shishi_verbose (Shishi * handle, const char *format, ...)
-    __attribute__ ((format (printf, 2, 3)));
+    __attribute__((format (printf, 2, 3)));
 
 /* realm.c */
   extern char *shishi_realm_default_guess (void);
@@ -694,13 +708,13 @@ extern "C"
   extern int shishi_principal_name (Shishi * handle,
 				    Shishi_asn1 namenode,
 				    const char *namefield,
-				    char **out, size_t * outlen);
+				    char **out, size_t *outlen);
   extern int shishi_principal_name_realm (Shishi * handle,
 					  Shishi_asn1 namenode,
 					  const char *namefield,
 					  Shishi_asn1 realmnode,
 					  const char *realmfield,
-					  char **out, size_t * outlen);
+					  char **out, size_t *outlen);
   extern int shishi_principal_name_set (Shishi * handle,
 					Shishi_asn1 namenode,
 					const char *namefield,
@@ -719,7 +733,7 @@ extern "C"
 /* ticket.c */
   extern Shishi_asn1 shishi_ticket (Shishi * handle);
   extern int shishi_ticket_server (Shishi * handle, Shishi_asn1 ticket,
-				   char **server, size_t * serverlen);
+				   char **server, size_t *serverlen);
   extern int shishi_ticket_sname_set (Shishi * handle,
 				      Shishi_asn1 ticket,
 				      Shishi_name_type name_type,
@@ -732,7 +746,7 @@ extern "C"
 				       const char *server);
   extern int shishi_ticket_realm_get (Shishi * handle,
 				      Shishi_asn1 ticket,
-				      char **realm, size_t * realmlen);
+				      char **realm, size_t *realmlen);
   extern int shishi_ticket_realm_set (Shishi * handle, Shishi_asn1 ticket,
 				      const char *realm);
   extern int shishi_ticket_get_enc_part_etype (Shishi * handle,
@@ -767,12 +781,12 @@ extern "C"
 				  Shishi_asn1 kdcrep);
   extern void shishi_tkt_pretty_print (Shishi_tkt * tkt, FILE * fh);
   extern int shishi_tkt_realm (Shishi_tkt * tkt, char **realm,
-			       size_t * realmlen);
+			       size_t *realmlen);
   extern int shishi_tkt_client (Shishi_tkt * tkt,
-				char **client, size_t * clientlen);
+				char **client, size_t *clientlen);
   extern int shishi_tkt_client_p (Shishi_tkt * tkt, const char *client);
   extern int shishi_tkt_clientrealm (Shishi_tkt * tkt,
-				     char **client, size_t * clientlen);
+				     char **client, size_t *clientlen);
   extern int shishi_tkt_clientrealm_p (Shishi_tkt * tkt, const char *client);
   extern int shishi_tkt_clientrealm_set (Shishi_tkt * tkt,
 					 const char *realm,
@@ -781,28 +795,28 @@ extern "C"
 					 const char *server);
   extern int shishi_tkt_build (Shishi_tkt * tkt, Shishi_key * key);
   extern int shishi_tkt_lastreq (Shishi_tkt * tkt,
-				 char **lrtime, size_t * lrtimelen,
+				 char **lrtime, size_t *lrtimelen,
 				 int32_t lrtype);
   extern time_t shishi_tkt_lastreqc (Shishi_tkt * tkt, Shishi_lrtype lrtype);
   extern void shishi_tkt_lastreq_pretty_print (Shishi_tkt * tkt, FILE * fh);
   extern int shishi_tkt_authtime (Shishi_tkt * tkt,
-				  char **authtime, size_t * authtimelen);
+				  char **authtime, size_t *authtimelen);
   extern time_t shishi_tkt_authctime (Shishi_tkt * tkt);
   extern int shishi_tkt_starttime (Shishi_tkt * tkt,
-				   char **starttime, size_t * starttimelen);
+				   char **starttime, size_t *starttimelen);
   extern time_t shishi_tkt_startctime (Shishi_tkt * tkt);
   extern int shishi_tkt_endtime (Shishi_tkt * tkt,
-				 char **endtime, size_t * endtimelen);
+				 char **endtime, size_t *endtimelen);
   extern time_t shishi_tkt_endctime (Shishi_tkt * tkt);
   extern int shishi_tkt_renew_till (Shishi_tkt * tkt,
 				    char **renewtilltime,
-				    size_t * renewtilllen);
+				    size_t *renewtilllen);
   extern time_t shishi_tkt_renew_tillc (Shishi_tkt * tkt);
   extern int shishi_tkt_keytype (Shishi_tkt * tkt, int32_t * etype);
   extern int32_t shishi_tkt_keytype_fast (Shishi_tkt * tkt);
   extern int shishi_tkt_keytype_p (Shishi_tkt * tkt, int32_t etype);
   extern int shishi_tkt_server (Shishi_tkt * tkt,
-				char **server, size_t * serverlen);
+				char **server, size_t *serverlen);
   extern int shishi_tkt_server_p (Shishi_tkt * tkt, const char *server);
   extern int shishi_tkt_valid_at_time_p (Shishi_tkt * tkt, time_t now);
   extern int shishi_tkt_valid_now_p (Shishi_tkt * tkt);
@@ -961,17 +975,17 @@ extern "C"
 						 uint32_t seqnumber);
   extern int shishi_authenticator_client (Shishi * handle,
 					  Shishi_asn1 authenticator,
-					  char **client, size_t * clientlen);
+					  char **client, size_t *clientlen);
   extern int shishi_authenticator_clientrealm (Shishi * handle,
 					       Shishi_asn1 authenticator,
 					       char **client,
-					       size_t * clientlen);
+					       size_t *clientlen);
   extern int shishi_authenticator_remove_cksum (Shishi * handle,
 						Shishi_asn1 authenticator);
   extern int shishi_authenticator_cksum (Shishi * handle,
 					 Shishi_asn1 authenticator,
 					 int32_t * cksumtype, char **cksum,
-					 size_t * cksumlen);
+					 size_t *cksumlen);
   extern int shishi_authenticator_set_cksum (Shishi * handle,
 					     Shishi_asn1 authenticator,
 					     int cksumtype, char *cksum,
@@ -1021,7 +1035,7 @@ extern "C"
     shishi_authenticator_authorizationdata (Shishi * handle,
 					    Shishi_asn1 authenticator,
 					    int32_t * adtype,
-					    char **addata, size_t * addatalen,
+					    char **addata, size_t *addatalen,
 					    size_t nth);
   extern int shishi_authenticator_read (Shishi * handle, FILE * fh,
 					Shishi_asn1 * authenticator);
@@ -1046,16 +1060,16 @@ extern "C"
   extern Shishi_asn1 shishi_as_req (Shishi_as * as);
   extern int shishi_as_req_build (Shishi_as * as);
   extern void shishi_as_req_set (Shishi_as * as, Shishi_asn1 asreq);
-  extern int shishi_as_req_der (Shishi_as * as, char **out, size_t * outlen);
+  extern int shishi_as_req_der (Shishi_as * as, char **out, size_t *outlen);
   extern int shishi_as_req_der_set (Shishi_as * as, char *der, size_t derlen);
   extern Shishi_asn1 shishi_as_rep (Shishi_as * as);
   extern void shishi_as_rep_set (Shishi_as * as, Shishi_asn1 asrep);
   extern int shishi_as_rep_build (Shishi_as * as, Shishi_key * key);
-  extern int shishi_as_rep_der (Shishi_as * as, char **out, size_t * outlen);
+  extern int shishi_as_rep_der (Shishi_as * as, char **out, size_t *outlen);
   extern int shishi_as_rep_der_set (Shishi_as * as, char *der, size_t derlen);
   extern Shishi_asn1 shishi_as_krberror (Shishi_as * as);
   extern int shishi_as_krberror_der (Shishi_as * as, char **out,
-				     size_t * outlen);
+				     size_t *outlen);
   extern void shishi_as_krberror_set (Shishi_as * as, Shishi_asn1 krberror);
   extern Shishi_tkt *shishi_as_tkt (Shishi_as * as);
   extern void shishi_as_tkt_set (Shishi_as * as, Shishi_tkt * tkt);
@@ -1073,7 +1087,7 @@ extern "C"
   extern Shishi_ap *shishi_tgs_ap (Shishi_tgs * tgs);
   extern Shishi_asn1 shishi_tgs_req (Shishi_tgs * tgs);
   extern int shishi_tgs_req_der (Shishi_tgs * tgs, char **out,
-				 size_t * outlen);
+				 size_t *outlen);
   extern int shishi_tgs_req_der_set (Shishi_tgs * tgs, char *der,
 				     size_t derlen);
   extern void shishi_tgs_req_set (Shishi_tgs * tgs, Shishi_asn1 tgsreq);
@@ -1081,13 +1095,13 @@ extern "C"
   extern int shishi_tgs_req_process (Shishi_tgs * tgs);
   extern Shishi_asn1 shishi_tgs_rep (Shishi_tgs * tgs);
   extern int shishi_tgs_rep_der (Shishi_tgs * tgs, char **out,
-				 size_t * outlen);
+				 size_t *outlen);
   extern int shishi_tgs_rep_build (Shishi_tgs * tgs, int keyusage,
 				   Shishi_key * key);
   extern int shishi_tgs_rep_process (Shishi_tgs * tgs);
   extern Shishi_asn1 shishi_tgs_krberror (Shishi_tgs * tgs);
   extern int shishi_tgs_krberror_der (Shishi_tgs * tgs, char **out,
-				      size_t * outlen);
+				      size_t *outlen);
   extern void shishi_tgs_krberror_set (Shishi_tgs * tgs,
 				       Shishi_asn1 krberror);
   extern Shishi_tkt *shishi_tgs_tkt (Shishi_tgs * tgs);
@@ -1124,25 +1138,25 @@ extern "C"
 				      int filetype, const char *filename);
   extern int shishi_asreq_clientrealm (Shishi * handle,
 				       Shishi_asn1 asreq,
-				       char **client, size_t * clientlen);
+				       char **client, size_t *clientlen);
   extern int shishi_kdcreq_nonce (Shishi * handle, Shishi_asn1 kdcreq,
 				  uint32_t * nonce);
   extern int shishi_kdcreq_nonce_set (Shishi * handle,
 				      Shishi_asn1 kdcreq, uint32_t nonce);
   extern int shishi_kdcreq_client (Shishi * handle, Shishi_asn1 kdcreq,
-				   char **client, size_t * clientlen);
+				   char **client, size_t *clientlen);
   extern int shishi_kdcreq_set_cname (Shishi * handle, Shishi_asn1 kdcreq,
 				      Shishi_name_type name_type,
 				      const char *principal);
   extern int shishi_kdcreq_server (Shishi * handle, Shishi_asn1 kdcreq,
-				   char **server, size_t * serverlen);
+				   char **server, size_t *serverlen);
   extern int shishi_kdcreq_set_sname (Shishi * handle, Shishi_asn1 kdcreq,
 				      Shishi_name_type name_type,
 				      const char *sname[]);
   extern int shishi_kdcreq_realm (Shishi * handle, Shishi_asn1 kdcreq,
-				  char **realm, size_t * realmlen);
+				  char **realm, size_t *realmlen);
   extern int shishi_kdcreq_realm_get (Shishi * handle, Shishi_asn1 kdcreq,
-				      char **realm, size_t * realmlen);
+				      char **realm, size_t *realmlen);
   extern int shishi_kdcreq_set_realm (Shishi * handle, Shishi_asn1 kdcreq,
 				      const char *realm);
   extern int shishi_kdcreq_set_server (Shishi * handle, Shishi_asn1 req,
@@ -1150,7 +1164,7 @@ extern "C"
   extern int shishi_kdcreq_set_realmserver (Shishi * handle, Shishi_asn1 req,
 					    char *realm, char *service);
   extern int shishi_kdcreq_till (Shishi * handle, Shishi_asn1 kdcreq,
-				 char **till, size_t * tilllen);
+				 char **till, size_t *tilllen);
   extern time_t shishi_kdcreq_tillc (Shishi * handle, Shishi_asn1 kdcreq);
   extern int shishi_kdcreq_etype (Shishi * handle, Shishi_asn1 kdcreq,
 				  int32_t * etype, int netype);
@@ -1183,7 +1197,7 @@ extern "C"
   extern int shishi_kdcreq_get_padata (Shishi * handle,
 				       Shishi_asn1 kdcreq,
 				       Shishi_padata_type padatatype,
-				       char **out, size_t * outlen);
+				       char **out, size_t *outlen);
   extern int shishi_kdcreq_get_padata_tgs (Shishi * handle,
 					   Shishi_asn1 kdcreq,
 					   Shishi_asn1 * apreq);
@@ -1203,7 +1217,7 @@ extern "C"
   extern int shishi_as_derive_salt (Shishi * handle,
 				    Shishi_asn1 asreq,
 				    Shishi_asn1 asrep,
-				    char **salt, size_t * saltlen);
+				    char **salt, size_t *saltlen);
   extern int shishi_tgs_process (Shishi * handle,
 				 Shishi_asn1 tgsreq,
 				 Shishi_asn1 tgsrep,
@@ -1348,10 +1362,10 @@ extern "C"
   extern int shishi_krberror_build (Shishi * handle, Shishi_asn1 krberror);
   extern int shishi_krberror_der (Shishi * handle,
 				  Shishi_asn1 krberror,
-				  char **out, size_t * outlen);
+				  char **out, size_t *outlen);
   extern int shishi_krberror_crealm (Shishi * handle,
 				     Shishi_asn1 krberror,
-				     char **realm, size_t * realmlen);
+				     char **realm, size_t *realmlen);
   extern int shishi_krberror_remove_crealm (Shishi * handle,
 					    Shishi_asn1 krberror);
   extern int shishi_krberror_set_crealm (Shishi * handle,
@@ -1359,7 +1373,7 @@ extern "C"
 					 const char *crealm);
   extern int shishi_krberror_client (Shishi * handle,
 				     Shishi_asn1 krberror,
-				     char **client, size_t * clientlen);
+				     char **client, size_t *clientlen);
   extern int shishi_krberror_set_cname (Shishi * handle,
 					Shishi_asn1 krberror,
 					Shishi_name_type name_type,
@@ -1371,13 +1385,13 @@ extern "C"
 					 const char *client);
   extern int shishi_krberror_realm (Shishi * handle,
 				    Shishi_asn1 krberror,
-				    char **realm, size_t * realmlen);
+				    char **realm, size_t *realmlen);
   extern int shishi_krberror_set_realm (Shishi * handle,
 					Shishi_asn1 krberror,
 					const char *realm);
   extern int shishi_krberror_server (Shishi * handle,
 				     Shishi_asn1 krberror,
-				     char **server, size_t * serverlen);
+				     char **server, size_t *serverlen);
   extern int shishi_krberror_remove_sname (Shishi * handle,
 					   Shishi_asn1 krberror);
   extern int shishi_krberror_set_sname (Shishi * handle,
@@ -1411,13 +1425,13 @@ extern "C"
 					    Shishi_asn1 krberror,
 					    int errorcode);
   extern int shishi_krberror_etext (Shishi * handle, Shishi_asn1 krberror,
-				    char **etext, size_t * etextlen);
+				    char **etext, size_t *etextlen);
   extern int shishi_krberror_set_etext (Shishi * handle, Shishi_asn1 krberror,
 					const char *etext);
   extern int shishi_krberror_remove_etext (Shishi * handle,
 					   Shishi_asn1 krberror);
   extern int shishi_krberror_edata (Shishi * handle, Shishi_asn1 krberror,
-				    char **edata, size_t * edatalen);
+				    char **edata, size_t *edatalen);
   extern int shishi_krberror_set_edata (Shishi * handle, Shishi_asn1 krberror,
 					const char *edata);
   extern int shishi_krberror_remove_edata (Shishi * handle,
@@ -1503,62 +1517,62 @@ extern "C"
   extern int shishi_encrypt_ivupdate_etype (Shishi * handle, Shishi_key * key,
 					    int keyusage, int32_t etype,
 					    const char *iv, size_t ivlen,
-					    char **ivout, size_t * ivoutlen,
+					    char **ivout, size_t *ivoutlen,
 					    const char *in, size_t inlen,
-					    char **out, size_t * outlen);
+					    char **out, size_t *outlen);
   extern int shishi_encrypt_iv_etype (Shishi * handle, Shishi_key * key,
 				      int keyusage, int32_t etype,
 				      const char *iv, size_t ivlen,
 				      const char *in, size_t inlen,
-				      char **out, size_t * outlen);
+				      char **out, size_t *outlen);
   extern int shishi_encrypt_etype (Shishi * handle, Shishi_key * key,
 				   int keyusage, int32_t etype,
 				   const char *in, size_t inlen, char **out,
-				   size_t * outlen);
+				   size_t *outlen);
   extern int shishi_encrypt_ivupdate (Shishi * handle, Shishi_key * key,
 				      int keyusage, const char *iv,
 				      size_t ivlen, char **ivout,
-				      size_t * ivoutlen, const char *in,
+				      size_t *ivoutlen, const char *in,
 				      size_t inlen, char **out,
-				      size_t * outlen);
+				      size_t *outlen);
   extern int shishi_encrypt_iv (Shishi * handle, Shishi_key * key,
 				int keyusage, const char *iv, size_t ivlen,
 				const char *in, size_t inlen, char **out,
-				size_t * outlen);
+				size_t *outlen);
   extern int shishi_encrypt (Shishi * handle, Shishi_key * key, int keyusage,
 			     char *in, size_t inlen, char **out,
-			     size_t * outlen);
+			     size_t *outlen);
   extern int shishi_decrypt_ivupdate_etype (Shishi * handle, Shishi_key * key,
 					    int keyusage, int32_t etype,
 					    const char *iv, size_t ivlen,
-					    char **ivout, size_t * ivoutlen,
+					    char **ivout, size_t *ivoutlen,
 					    const char *in, size_t inlen,
-					    char **out, size_t * outlen);
+					    char **out, size_t *outlen);
   extern int shishi_decrypt_iv_etype (Shishi * handle, Shishi_key * key,
 				      int keyusage, int32_t etype,
 				      const char *iv, size_t ivlen,
 				      const char *in, size_t inlen,
-				      char **out, size_t * outlen);
+				      char **out, size_t *outlen);
   extern int shishi_decrypt_etype (Shishi * handle, Shishi_key * key,
 				   int keyusage, int32_t etype,
 				   const char *in, size_t inlen, char **out,
-				   size_t * outlen);
+				   size_t *outlen);
   extern int shishi_decrypt_ivupdate (Shishi * handle, Shishi_key * key,
 				      int keyusage, const char *iv,
 				      size_t ivlen, char **ivout,
-				      size_t * ivoutlen, const char *in,
+				      size_t *ivoutlen, const char *in,
 				      size_t inlen, char **out,
-				      size_t * outlen);
+				      size_t *outlen);
   extern int shishi_decrypt_iv (Shishi * handle, Shishi_key * key,
 				int keyusage, const char *iv, size_t ivlen,
 				const char *in, size_t inlen, char **out,
-				size_t * outlen);
+				size_t *outlen);
   extern int shishi_decrypt (Shishi * handle, Shishi_key * key, int keyusage,
 			     const char *in, size_t inlen, char **out,
-			     size_t * outlen);
+			     size_t *outlen);
   extern int shishi_checksum (Shishi * handle, Shishi_key * key, int keyusage,
 			      int32_t cksumtype, const char *in, size_t inlen,
-			      char **out, size_t * outlen);
+			      char **out, size_t *outlen);
   extern int shishi_verify (Shishi * handle, Shishi_key * key, int keyusage,
 			    int cksumtype, const char *in, size_t inlen,
 			    const char *cksum, size_t cksumlen);
@@ -1582,10 +1596,10 @@ extern "C"
   extern void shishi_crypto_close (Shishi_crypto * ctx);
   extern int shishi_crypto_encrypt (Shishi_crypto * ctx,
 				    const char *in, size_t inlen,
-				    char **out, size_t * outlen);
+				    char **out, size_t *outlen);
   extern int shishi_crypto_decrypt (Shishi_crypto * ctx,
 				    const char *in, size_t inlen,
-				    char **out, size_t * outlen);
+				    char **out, size_t *outlen);
 
 /* version.c */
   extern const char *shishi_check_version (const char *req_version);
@@ -1606,16 +1620,16 @@ extern "C"
 /* asn1.c */
   extern int shishi_asn1_number_of_elements (Shishi * handle,
 					     Shishi_asn1 node,
-					     const char *field, size_t * n);
+					     const char *field, size_t *n);
   extern int shishi_asn1_empty_p (Shishi * handle, Shishi_asn1 node,
 				  const char *field);
 
   extern int shishi_asn1_read (Shishi * handle, Shishi_asn1 node,
 			       const char *field,
-			       char **data, size_t * datalen);
+			       char **data, size_t *datalen);
   extern int shishi_asn1_read_inline (Shishi * handle, Shishi_asn1 node,
 				      const char *field,
-				      char *data, size_t * datalen);
+				      char *data, size_t *datalen);
   extern int shishi_asn1_read_integer (Shishi * handle, Shishi_asn1 node,
 				       const char *field, int *i);
   extern int shishi_asn1_read_int32 (Shishi * handle, Shishi_asn1 node,
@@ -1626,7 +1640,7 @@ extern "C"
 					 const char *field, uint32_t * flags);
   extern int shishi_asn1_read_optional (Shishi * handle,
 					Shishi_asn1 node, const char *field,
-					char **data, size_t * datalen);
+					char **data, size_t *datalen);
 
   extern int shishi_asn1_write (Shishi * handle, Shishi_asn1 node,
 				const char *field,
@@ -1666,10 +1680,10 @@ extern "C"
   extern Shishi_asn1 shishi_asn1_encprivpart (Shishi * handle);
 
   extern int shishi_asn1_to_der (Shishi * handle, Shishi_asn1 node,
-				 char **der, size_t * len);
+				 char **der, size_t *len);
   extern int shishi_asn1_to_der_field (Shishi * handle, Shishi_asn1 node,
 				       const char *field,
-				       char **der, size_t * len);
+				       char **der, size_t *len);
 
   extern Shishi_msgtype shishi_asn1_msgtype (Shishi * handle,
 					     Shishi_asn1 node);
@@ -1792,7 +1806,7 @@ extern "C"
   extern void shishi_ap_tkt_set (Shishi_ap * ap, Shishi_tkt * tkt);
 
   extern int shishi_ap_authenticator_cksumdata (Shishi_ap * ap,
-						char *out, size_t * len);
+						char *out, size_t *len);
   extern void
     shishi_ap_authenticator_cksumdata_set (Shishi_ap * ap,
 					   const char *authenticatorcksumdata,
@@ -1812,7 +1826,7 @@ extern "C"
 
   extern Shishi_asn1 shishi_ap_req (Shishi_ap * ap);
   extern void shishi_ap_req_set (Shishi_ap * ap, Shishi_asn1 apreq);
-  extern int shishi_ap_req_der (Shishi_ap * ap, char **out, size_t * outlen);
+  extern int shishi_ap_req_der (Shishi_ap * ap, char **out, size_t *outlen);
   extern int shishi_ap_req_der_set (Shishi_ap * ap, char *der, size_t derlen);
   extern int shishi_ap_req_build (Shishi_ap * ap);
   extern int shishi_ap_req_asn1 (Shishi_ap * ap, Shishi_asn1 * apreq);
@@ -1825,7 +1839,7 @@ extern "C"
 
   extern Shishi_asn1 shishi_ap_rep (Shishi_ap * ap);
   extern void shishi_ap_rep_set (Shishi_ap * ap, Shishi_asn1 aprep);
-  extern int shishi_ap_rep_der (Shishi_ap * ap, char **out, size_t * outlen);
+  extern int shishi_ap_rep_der (Shishi_ap * ap, char **out, size_t *outlen);
   extern int shishi_ap_rep_der_set (Shishi_ap * ap, char *der, size_t derlen);
   extern int shishi_ap_rep_verify (Shishi_ap * ap);
   extern int shishi_ap_rep_verify_der (Shishi_ap * ap, char *der,
@@ -1935,7 +1949,7 @@ extern "C"
 					   Shishi_keys ** outkeys);
   extern int shishi_keys_to_keytab_mem (Shishi * handle,
 					Shishi_keys * keys,
-					char **out, size_t * len);
+					char **out, size_t *len);
   extern int shishi_keys_to_keytab_file (Shishi * handle,
 					 Shishi_keys * keys,
 					 const char *filename);
@@ -2081,10 +2095,10 @@ extern "C"
 /* netio.c */
   extern int shishi_kdc_sendrecv (Shishi * handle, const char *realm,
 				  const char *indata, size_t inlen,
-				  char **outdata, size_t * outlen);
+				  char **outdata, size_t *outlen);
   extern int shishi_kdc_sendrecv_hint (Shishi * handle, const char *realm,
 				       const char *indata, size_t inlen,
-				       char **outdata, size_t * outlen,
+				       char **outdata, size_t *outlen,
 				       Shishi_tkts_hint * hint);
 
 /* encticketpart.c */
@@ -2097,17 +2111,17 @@ extern "C"
 					   Shishi_key ** key);
   extern int shishi_encticketpart_crealm (Shishi * handle,
 					  Shishi_asn1 encticketpart,
-					  char **crealm, size_t * crealmlen);
+					  char **crealm, size_t *crealmlen);
   extern int shishi_encticketpart_crealm_set (Shishi * handle,
 					      Shishi_asn1 encticketpart,
 					      const char *realm);
   extern int shishi_encticketpart_client (Shishi * handle,
 					  Shishi_asn1 encticketpart,
-					  char **client, size_t * clientlen);
+					  char **client, size_t *clientlen);
   extern int shishi_encticketpart_clientrealm (Shishi * handle,
 					       Shishi_asn1 encticketpart,
 					       char **client,
-					       size_t * clientlen);
+					       size_t *clientlen);
   extern int shishi_encticketpart_cname_set (Shishi * handle,
 					     Shishi_asn1 encticketpart,
 					     Shishi_name_type name_type,
@@ -2131,7 +2145,7 @@ extern "C"
   extern int shishi_encticketpart_authtime (Shishi * handle,
 					    Shishi_asn1 encticketpart,
 					    char *authtime,
-					    size_t * authtimelen);
+					    size_t *authtimelen);
   extern time_t shishi_encticketpart_authctime (Shishi * handle,
 						Shishi_asn1 encticketpart);
 
@@ -2143,7 +2157,7 @@ extern "C"
   extern Shishi_asn1 shishi_safe_safe (Shishi_safe * safe);
   extern void shishi_safe_safe_set (Shishi_safe * safe, Shishi_asn1 asn1safe);
   extern int shishi_safe_safe_der (Shishi_safe * safe, char **out,
-				   size_t * outlen);
+				   size_t *outlen);
   extern int shishi_safe_safe_der_set (Shishi_safe * safe,
 				       char *der, size_t derlen);
   extern int shishi_safe_print (Shishi * handle, FILE * fh, Shishi_asn1 safe);
@@ -2158,12 +2172,12 @@ extern "C"
 				    int filetype, const char *filename);
   extern int shishi_safe_cksum (Shishi * handle, Shishi_asn1 safe,
 				int32_t * cksumtype, char **cksum,
-				size_t * cksumlen);
+				size_t *cksumlen);
   extern int shishi_safe_set_cksum (Shishi * handle, Shishi_asn1 safe,
 				    int32_t cksumtype, const char *cksum,
 				    size_t cksumlen);
   extern int shishi_safe_user_data (Shishi * handle, Shishi_asn1 safe,
-				    char **userdata, size_t * userdatalen);
+				    char **userdata, size_t *userdatalen);
   extern int shishi_safe_set_user_data (Shishi * handle, Shishi_asn1 safe,
 					const char *userdata,
 					size_t userdatalen);
@@ -2178,14 +2192,14 @@ extern "C"
   extern Shishi_asn1 shishi_priv_priv (Shishi_priv * priv);
   extern void shishi_priv_priv_set (Shishi_priv * priv, Shishi_asn1 asn1priv);
   extern int shishi_priv_priv_der (Shishi_priv * priv, char **out,
-				   size_t * outlen);
+				   size_t *outlen);
   extern int shishi_priv_priv_der_set (Shishi_priv * priv,
 				       char *der, size_t derlen);
   extern Shishi_asn1 shishi_priv_encprivpart (Shishi_priv * priv);
   extern void shishi_priv_encprivpart_set (Shishi_priv * priv,
 					   Shishi_asn1 asn1encprivpart);
   extern int shishi_priv_encprivpart_der (Shishi_priv * priv, char **out,
-					  size_t * outlen);
+					  size_t *outlen);
   extern int shishi_priv_encprivpart_der_set (Shishi_priv * priv,
 					      char *der, size_t derlen);
   extern int shishi_priv_print (Shishi * handle, FILE * fh, Shishi_asn1 priv);
@@ -2206,7 +2220,7 @@ extern "C"
   extern int shishi_encprivpart_user_data (Shishi * handle,
 					   Shishi_asn1 encprivpart,
 					   char **userdata,
-					   size_t * userdatalen);
+					   size_t *userdatalen);
   extern int shishi_encprivpart_set_user_data (Shishi * handle,
 					       Shishi_asn1 encprivpart,
 					       const char *userdata,
@@ -2242,9 +2256,9 @@ extern "C"
 /* Ugly hack to avoid re-declaring shishi_xalloc_die twice.  It is
    already declared in xalloc.h internally in Shishi.h.  This is to
    keep being able to use -Wredundant-decls. */
-#if defined SYSTEMCFGFILE && !defined XALLOC_H_
-  extern void shishi_xalloc_die (void) __attribute__ ((__noreturn__));
-#endif
+# if defined SYSTEMCFGFILE && !defined XALLOC_H_
+  extern void shishi_xalloc_die (void) __attribute__((__noreturn__));
+# endif
 
 /* resolv.c */
   extern Shishi_dns shishi_resolv (const char *zone, uint16_t querytype);
