@@ -1,5 +1,5 @@
 /* starttls.c --- Network I/O functions for Shishi over TLS.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -85,9 +85,9 @@ _shishi_tls_done (Shishi * handle)
 static int
 _shishi_sendrecv_tls1 (Shishi * handle,
 		       int sockfd,
-		       gnutls_session session,
+		       gnutls_session_t session,
 		       const char *indata, size_t inlen,
-		       char **outdata, size_t * outlen,
+		       char **outdata, size_t *outlen,
 		       size_t timeout, bool have_cas)
 {
   int ret;
@@ -107,7 +107,7 @@ _shishi_sendrecv_tls1 (Shishi * handle,
       memcmp (extbuf, STARTTLS_SERVER_ACCEPT, STARTTLS_LEN) != 0)
     return SHISHI_RECVFROM_ERROR;
 
-  gnutls_transport_set_ptr (session, (gnutls_transport_ptr)
+  gnutls_transport_set_ptr (session, (gnutls_transport_ptr_t)
 			    (unsigned long) sockfd);
 
   if (session_data_size > 0)
@@ -132,7 +132,7 @@ _shishi_sendrecv_tls1 (Shishi * handle,
       if (ret != 0 || status != 0)
 	{
 	  shishi_error_printf (handle,
-			       "TLS verification of CA failed (%d/%d)", ret,
+			       "TLS verification of CA failed (%d/%u)", ret,
 			       status);
 	  return SHISHI_RECVFROM_ERROR;
 	}
@@ -168,14 +168,14 @@ _shishi_sendrecv_tls1 (Shishi * handle,
   bytes_sent = gnutls_record_send (session, tmpbuf, 4);
   if (bytes_sent != 4)
     {
-      shishi_error_printf (handle, "Bad TLS write (%d < 4)", bytes_sent);
+      shishi_error_printf (handle, "Bad TLS write (%zd < 4)", bytes_sent);
       return SHISHI_SENDTO_ERROR;
     }
 
   bytes_sent = gnutls_record_send (session, indata, inlen);
   if (bytes_sent != (ssize_t) inlen)
     {
-      shishi_error_printf (handle, "Bad TLS write (%d < %d)",
+      shishi_error_printf (handle, "Bad TLS write (%zd < %zu)",
 			   bytes_sent, inlen);
       return SHISHI_SENDTO_ERROR;
     }
@@ -183,7 +183,7 @@ _shishi_sendrecv_tls1 (Shishi * handle,
   bytes_read = gnutls_record_recv (session, tmpbuf, 4);
   if (bytes_read != 4)
     {
-      shishi_error_printf (handle, "Bad TLS read (%d < 4)", bytes_read);
+      shishi_error_printf (handle, "Bad TLS read (%zd < 4)", bytes_read);
       return SHISHI_SENDTO_ERROR;
     }
 
@@ -207,7 +207,7 @@ _shishi_sendrecv_tls1 (Shishi * handle,
     }
   else if (bytes_read != (ssize_t) * outlen)
     {
-      shishi_error_printf (handle, "TLS Read error (%d != %d)",
+      shishi_error_printf (handle, "TLS Read error (%zu != %zd)",
 			   *outlen, bytes_read);
       free (*outdata);
       return SHISHI_RECVFROM_ERROR;
@@ -229,11 +229,11 @@ int
 _shishi_sendrecv_tls (Shishi * handle,
 		      struct addrinfo *ai,
 		      const char *indata, size_t inlen,
-		      char **outdata, size_t * outlen)
+		      char **outdata, size_t *outlen)
 {
-  gnutls_session session;
-  gnutls_anon_client_credentials anoncred;
-  gnutls_certificate_credentials x509cred;
+  gnutls_session_t session;
+  gnutls_anon_client_credentials_t anoncred;
+  gnutls_certificate_credentials_t x509cred;
   int sockfd;
   int ret, outerr;
   const char *cafile = shishi_x509ca_default_file (handle);
@@ -263,7 +263,8 @@ _shishi_sendrecv_tls (Shishi * handle,
       return SHISHI_CRYPTO_ERROR;
     }
 
-  ret = gnutls_priority_set_direct (session, "NORMAL:+ANON-DH", NULL);
+  ret =
+    gnutls_priority_set_direct (session, "NORMAL:+ANON-ECDH:+ANON-DH", NULL);
   if (ret != GNUTLS_E_SUCCESS)
     {
       shishi_error_printf (handle, "TLS psd failed (%d): %s",
