@@ -1,5 +1,5 @@
 /* ticket.c --- Low-level ASN.1 Ticket handling.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -70,7 +70,7 @@ error:
  **/
 int
 shishi_ticket_realm_get (Shishi * handle,
-			 Shishi_asn1 ticket, char **realm, size_t * realmlen)
+			 Shishi_asn1 ticket, char **realm, size_t *realmlen)
 {
   return shishi_asn1_read (handle, ticket, "realm", realm, realmlen);
 }
@@ -116,7 +116,7 @@ shishi_ticket_realm_set (Shishi * handle, Shishi_asn1 ticket,
  **/
 int
 shishi_ticket_server (Shishi * handle, Shishi_asn1 ticket,
-		      char **server, size_t * serverlen)
+		      char **server, size_t *serverlen)
 {
   return shishi_principal_name (handle, ticket, "sname", server, serverlen);
 }
@@ -142,7 +142,7 @@ shishi_ticket_sname_set (Shishi * handle,
   char *buf;
   int i;
 
-  asprintf (&buf, "%d", name_type);
+  asprintf (&buf, "%u", name_type);
   res = shishi_asn1_write (handle, ticket, "sname.name-type", buf, 0);
   free (buf);
   if (res != SHISHI_OK)
