@@ -1,5 +1,5 @@
 /* tkt.c --- Ticket handling.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -395,7 +395,7 @@ shishi_tkt_serverrealm_set (Shishi_tkt * tkt,
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_tkt_client (Shishi_tkt * tkt, char **client, size_t * clientlen)
+shishi_tkt_client (Shishi_tkt * tkt, char **client, size_t *clientlen)
 {
   return shishi_principal_name (tkt->handle, tkt->kdcrep,
 				"cname", client, clientlen);
@@ -444,7 +444,7 @@ shishi_tkt_client_p (Shishi_tkt * tkt, const char *client)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_tkt_clientrealm (Shishi_tkt * tkt, char **client, size_t * clientlen)
+shishi_tkt_clientrealm (Shishi_tkt * tkt, char **client, size_t *clientlen)
 {
   return shishi_principal_name_realm (tkt->handle,
 				      tkt->kdcrep, "cname",
@@ -490,7 +490,7 @@ shishi_tkt_clientrealm_p (Shishi_tkt * tkt, const char *client)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_tkt_realm (Shishi_tkt * tkt, char **realm, size_t * realmlen)
+shishi_tkt_realm (Shishi_tkt * tkt, char **realm, size_t *realmlen)
 {
   return shishi_ticket_realm_get (tkt->handle, tkt->ticket, realm, realmlen);
 }
@@ -511,7 +511,7 @@ shishi_tkt_realm (Shishi_tkt * tkt, char **realm, size_t * realmlen)
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_tkt_server (Shishi_tkt * tkt, char **server, size_t * serverlen)
+shishi_tkt_server (Shishi_tkt * tkt, char **server, size_t *serverlen)
 {
   return shishi_ticket_server (tkt->handle, tkt->ticket, server, serverlen);
 }
@@ -1049,7 +1049,7 @@ shishi_tkt_keytype_p (Shishi_tkt * tkt, int32_t etype)
 
 int
 shishi_tkt_lastreq (Shishi_tkt * tkt,
-		    char **lrtime, size_t * lrtimelen, int32_t lrtype)
+		    char **lrtime, size_t *lrtimelen, int32_t lrtype)
 {
   char *format;
   int32_t tmplrtype;
@@ -1063,7 +1063,7 @@ shishi_tkt_lastreq (Shishi_tkt * tkt,
 
   for (i = 1; i <= n; i++)
     {
-      asprintf (&format, "last-req.?%d.lr-type", i);
+      asprintf (&format, "last-req.?%zu.lr-type", i);
       res = shishi_asn1_read_int32 (tkt->handle, tkt->enckdcreppart,
 				    format, &tmplrtype);
       free (format);
@@ -1072,7 +1072,7 @@ shishi_tkt_lastreq (Shishi_tkt * tkt,
 
       if (lrtype == tmplrtype)
 	{
-	  asprintf (&format, "last-req.?%d.lr-value", i);
+	  asprintf (&format, "last-req.?%zu.lr-value", i);
 	  res = shishi_asn1_read (tkt->handle, tkt->enckdcreppart,
 				  format, lrtime, lrtimelen);
 	  free (format);
@@ -1119,7 +1119,7 @@ shishi_tkt_lastreqc (Shishi_tkt * tkt, Shishi_lrtype lrtype)
 }
 
 int
-shishi_tkt_authtime (Shishi_tkt * tkt, char **authtime, size_t * authtimelen)
+shishi_tkt_authtime (Shishi_tkt * tkt, char **authtime, size_t *authtimelen)
 {
   return shishi_asn1_read (tkt->handle, tkt->enckdcreppart, "authtime",
 			   authtime, authtimelen);
@@ -1157,7 +1157,7 @@ shishi_tkt_authctime (Shishi_tkt * tkt)
 
 int
 shishi_tkt_starttime (Shishi_tkt * tkt,
-		      char **starttime, size_t * starttimelen)
+		      char **starttime, size_t *starttimelen)
 {
   return shishi_asn1_read_optional (tkt->handle, tkt->enckdcreppart,
 				    "starttime", starttime, starttimelen);
@@ -1194,7 +1194,7 @@ shishi_tkt_startctime (Shishi_tkt * tkt)
 }
 
 int
-shishi_tkt_endtime (Shishi_tkt * tkt, char **endtime, size_t * endtimelen)
+shishi_tkt_endtime (Shishi_tkt * tkt, char **endtime, size_t *endtimelen)
 {
   return shishi_asn1_read (tkt->handle, tkt->enckdcreppart, "endtime",
 			   endtime, endtimelen);
@@ -1231,7 +1231,7 @@ shishi_tkt_endctime (Shishi_tkt * tkt)
 
 int
 shishi_tkt_renew_till (Shishi_tkt * tkt,
-		       char **renewtill, size_t * renewtilllen)
+		       char **renewtill, size_t *renewtilllen)
 {
   return shishi_asn1_read_optional (tkt->handle, tkt->enckdcreppart,
 				    "renew-till", renewtill, renewtilllen);
@@ -1464,7 +1464,7 @@ shishi_tkt_pretty_print (Shishi_tkt * tkt, FILE * fh)
 	fprintf (fh, "TRANSITEDPOLICYCHECKED ");
       if (shishi_tkt_ok_as_delegate_p (tkt))
 	fprintf (fh, "OKASDELEGATE ");
-      fprintf (fh, "(%d)\n", flags);
+      fprintf (fh, "(%" PRIu32 ")\n", flags);
     }
 }
 
