@@ -1,5 +1,5 @@
 /* ccache.c --- Credential Cache compatibility ticket set handling.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -124,7 +124,7 @@ shishi_tkts_add_ccache_mem (Shishi * handle,
 
   if (VERBOSENOISE (handle))
     {
-      printf ("ccache len %d (0x%x)\n", len, len);
+      printf ("ccache len %zu (0x%zx)\n", len, len);
       _shishi_hexprint (data, len);
     }
 
@@ -328,7 +328,7 @@ shishi_tkts_add_ccache_file (Shishi * handle,
 			     const char *filename, Shishi_tkts * tkts)
 {
   size_t len;
-  char *ccache = read_binary_file (filename, &len);
+  char *ccache = read_file (filename, RF_BINARY, &len);
   int rc;
 
   if (!ccache)
@@ -422,11 +422,11 @@ shishi_tkts_from_ccache_file (Shishi * handle,
 
 extern int
 shishi_tkt_to_ccache_mem (Shishi * handle, Shishi_tkt * tkt,
-			  char **data, size_t * len);
+			  char **data, size_t *len);
 
 int
 shishi_tkt_to_ccache_mem (Shishi * handle,
-			  Shishi_tkt * tkt, char **data, size_t * len)
+			  Shishi_tkt * tkt, char **data, size_t *len)
 {
 #if 0
   struct ccache_credential cred;
@@ -458,7 +458,7 @@ shishi_tkt_to_ccache_mem (Shishi * handle,
 
   return SHISHI_OK;
 
-#if 0
+# if 0
   {
     char *cname[CCACHE_MAX_COMPONENTS + 1];
     size_t i;
@@ -502,7 +502,7 @@ shishi_tkt_to_ccache_mem (Shishi * handle,
     if (rc != SHISHI_OK)
       return rc;
   }
-#endif
+# endif
 
   rc = shishi_tkt_flags (tkt, &cred.tktflags);
   if (rc != SHISHI_OK)
@@ -576,11 +576,11 @@ shishi_tkt_to_ccache_mem (Shishi * handle,
 
 extern int
 shishi_tkts_to_ccache_mem (Shishi * handle, Shishi_tkts * tkts,
-			   char **data, size_t * len);
+			   char **data, size_t *len);
 
 int
 shishi_tkts_to_ccache_mem (Shishi * handle,
-			   Shishi_tkts * tkts, char **data, size_t * len)
+			   Shishi_tkts * tkts, char **data, size_t *len)
 {
   return SHISHI_CCACHE_ERROR;
 
