@@ -1,5 +1,5 @@
 /* ccache2shishi.c --- Print and convert MIT ccache files.
- * Copyright (C) 2006-2013 Simon Josefsson
+ * Copyright (C) 2006-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -135,8 +135,8 @@ main (int argc, char *argv[])
 	if (ntkts == 0)
 	  printf (_("No tickets written.\n"));
 	else
-	  printf (ngettext ("%d ticket written.\n",
-			    "%d tickets written.\n", ntkts), ntkts);
+	  printf (ngettext ("%zu ticket written.\n",
+			    "%zu tickets written.\n", ntkts), ntkts);
       }
 
     shishi_tkts_done (&tkts);
