@@ -1,5 +1,5 @@
 /* kdc.c --- Process AS and TGS requests.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -20,7 +20,12 @@
  *
  */
 
-/* Note: only use syslog to report errors in this file. */
+/* Note: only use syslog to report errors in this file.
+ *
+ * XXX: Examine in detail the made choices of syslog facility.
+ *      Messages should not exessively use 'auth', be it as default
+ *      by openlog(), or explicitly.
+ */
 
 /* Get Shishid stuff. */
 #include "kdc.h"
@@ -116,8 +121,8 @@ asreq1 (Shishi_as * as)
   if (rc == SHISA_NO_PRINCIPAL)
     {
       syslog (LOG_NOTICE,
-	      "AS-REQ from %s@%s for %s@%s failed: no such server", username,
-	      realm, servername, realm);
+	      "AS-REQ from %s@%s for %s@%s failed: no such server",
+	      username, realm, servername, realm);
       rc =
 	shishi_krberror_errorcode_set (handle, shishi_as_krberror (as),
 				       SHISHI_KDC_ERR_S_PRINCIPAL_UNKNOWN);
@@ -184,6 +189,7 @@ asreq1 (Shishi_as * as)
       if (userdbkey == NULL)
 	for (j = 0; j < nuserkeys; j++)
 	  {
+	    /* Keep facility coordinated with 'AS-REQ from ...'.  */
 	    syslog (LOG_DEBUG,
 		    "Matching client etype %d against user key etype %d",
 		    etype, userkeys[j]->etype);
@@ -194,6 +200,7 @@ asreq1 (Shishi_as * as)
 
   if (userdbkey == NULL)
     {
+      /* Again keeping facility coordinated with 'AS-REQ from ...'.  */
       syslog (LOG_NOTICE, "No matching client keys for %s@%s",
 	      username, realm);
       rc = shishi_krberror_errorcode_set (handle, shishi_as_krberror (as),
@@ -353,8 +360,8 @@ asreq1 (Shishi_as * as)
 
     if (tilllen != 16 || strlen (till) != 15)
       {
-	syslog (LOG_ERR, "Invalid 'till' field in request (%d): %s", tilllen,
-		till);
+	syslog (LOG_ERR, "Invalid 'till' field in request (%zu): %s",
+		tilllen, till);
 	goto fatal;
       }
 
@@ -990,7 +997,7 @@ fatal:
 }
 
 static int
-asreq (Shishi_asn1 kdcreq, char **out, size_t * outlen)
+asreq (Shishi_asn1 kdcreq, char **out, size_t *outlen)
 {
   Shishi_as *as;
   int rc;
@@ -1024,7 +1031,7 @@ asreq (Shishi_asn1 kdcreq, char **out, size_t * outlen)
 }
 
 static int
-tgsreq (Shishi_asn1 kdcreq, char **out, size_t * outlen)
+tgsreq (Shishi_asn1 kdcreq, char **out, size_t *outlen)
 {
   Shishi_tgs *tgs;
   int rc;
@@ -1068,7 +1075,7 @@ process (const char *in, size_t inlen, char **out)
   node = shishi_der2asn1 (handle, in, inlen);
   if (node == NULL)
     {
-      syslog (LOG_ERR, "Received %d bytes of unknown data", inlen);
+      syslog (LOG_ERR, "Received %zu bytes of unknown data", inlen);
       return -1;
     }
 
@@ -1093,7 +1100,7 @@ process (const char *in, size_t inlen, char **out)
     case SHISHI_MSGTYPE_CRED:
     case SHISHI_MSGTYPE_ERROR:
     default:
-      syslog (LOG_ERR, "Unsupported KDC message type %d (0x%x)",
+      syslog (LOG_ERR, "Unsupported KDC message type %u (0x%x)",
 	      shishi_asn1_msgtype (handle, node),
 	      shishi_asn1_msgtype (handle, node));
       rc = SHISHI_ASN1_ERROR;
