@@ -1,5 +1,5 @@
 /* server.c --- Handle KDC sessions.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -50,7 +50,8 @@ kdc_accept (struct listenspec *ls)
     strcpy (newls->addrname, "unknown address");
   asprintf (&newls->str, "%s (%s)", newls->addrname, ls->str);
 
-  syslog (LOG_DEBUG, "Accepted socket %d from socket %d as %s",
+  syslog (LOG_DEBUG | LOG_DAEMON,
+	  "Accepted socket %d from socket %d as %s",
 	  newls->sockfd, ls->sockfd, newls->str);
 }
 
@@ -63,7 +64,8 @@ kdc_close (struct listenspec *ls)
   struct listenspec *tmp;
   int rc;
 
-  syslog (LOG_INFO, "Closing %s socket %d", ls->str, ls->sockfd);
+  syslog (LOG_DEBUG | LOG_DAEMON,
+	  "Closing %s socket %d", ls->str, ls->sockfd);
 
 #ifdef USE_STARTTLS
   if (ls->usetls)
@@ -73,7 +75,8 @@ kdc_close (struct listenspec *ls)
       while (rc == GNUTLS_E_AGAIN || rc == GNUTLS_E_INTERRUPTED);
 
       if (rc != GNUTLS_E_SUCCESS)
-	syslog (LOG_ERR, "TLS terminate failed to %s on socket %d (%d): %s",
+	syslog (LOG_ERR | LOG_DAEMON,
+		"TLS terminate failed to %s on socket %d (%d): %s",
 		ls->str, ls->sockfd, rc, gnutls_strerror (rc));
 
       gnutls_deinit (ls->session);
@@ -84,7 +87,8 @@ kdc_close (struct listenspec *ls)
     {
       rc = close (ls->sockfd);
       if (rc != 0)
-	syslog (LOG_ERR, "Close failed to %s on socket %d (%d): %s",
+	syslog (LOG_ERR | LOG_DAEMON,
+		"Close failed to %s on socket %d (%d): %s",
 		ls->str, ls->sockfd, rc, strerror (rc));
     }
 
@@ -121,13 +125,16 @@ kdc_send1 (struct listenspec *ls)
   while (sent_bytes == -1 && errno == EAGAIN);
 
   if (sent_bytes < 0)
-    syslog (LOG_ERR, "Error writing %d bytes to %s on socket %d: %s",
+    syslog (LOG_ERR | LOG_DAEMON,
+	    "Error writing %zu bytes to %s on socket %d: %s",
 	    ls->bufpos, ls->str, ls->sockfd, strerror (errno));
   else if ((size_t) sent_bytes > ls->bufpos)
-    syslog (LOG_ERR, "Overlong write (%d > %d) to %s on socket %d",
+    syslog (LOG_ERR | LOG_DAEMON,
+	    "Overlong write (%zd > %zu) to %s on socket %d",
 	    sent_bytes, ls->bufpos, ls->str, ls->sockfd);
   else if ((size_t) sent_bytes < ls->bufpos)
-    syslog (LOG_ERR, "Short write (%d < %d) to %s on socket %d",
+    syslog (LOG_ERR | LOG_DAEMON,
+	    "Short write (%zd < %zu) to %s on socket %d",
 	    sent_bytes, ls->bufpos, ls->str, ls->sockfd);
 }
 
@@ -137,11 +144,13 @@ static void
 kdc_send (struct listenspec *ls)
 {
   if (ls->ai.ai_socktype == SOCK_DGRAM)
-    syslog (LOG_DEBUG, "Sending %d bytes to %s socket %d via UDP",
+    syslog (LOG_DEBUG | LOG_DAEMON,
+	    "Sending %zu bytes to %s socket %d via UDP",
 	    ls->bufpos, ls->clientaddrname, ls->sockfd);
   else
     {
-      syslog (LOG_DEBUG, "Sending %d bytes to %s socket %d via %s",
+      syslog (LOG_DEBUG | LOG_DAEMON,
+	      "Sending %zu bytes to %s socket %d via %s",
 	      ls->bufpos, ls->str, ls->sockfd, ls->usetls ? "TLS" : "TCP");
 
       if (ls->bufpos + 4 >= sizeof (ls->buf))
@@ -168,8 +177,8 @@ kdc_extension_reject (struct listenspec *ls)
   size_t derlen;
   int rc;
 
-  syslog (LOG_INFO, "Reject extension from %s on socket %d",
-	  ls->str, ls->sockfd);
+  syslog (LOG_NOTICE | LOG_AUTH,
+	  "Reject extension from %s on socket %d", ls->str, ls->sockfd);
 
   krberr = shishi_krberror (handle);
   if (!krberr)
@@ -180,7 +189,7 @@ kdc_extension_reject (struct listenspec *ls)
   if (rc != SHISHI_OK)
     return rc;
 
-  rc = shishi_krberror_set_etext (handle, krberr, "Extension not support");
+  rc = shishi_krberror_set_etext (handle, krberr, "Extension not supported");
   if (rc != SHISHI_OK)
     return rc;
 
@@ -242,20 +251,22 @@ kdc_read (struct listenspec *ls)
     {
 #ifdef USE_STARTTLS
       if (ls->usetls)
-	syslog (LOG_ERR, "Corrupt TLS data from %s on socket %d (%d): %s",
+	syslog (LOG_ERR | LOG_DAEMON,
+		"Corrupt TLS data from %s on socket %d (%zd): %s",
 		ls->str, ls->sockfd, read_bytes,
 		gnutls_strerror (read_bytes));
       else
 #endif
-	syslog (LOG_ERR, "Error reading from %s on socket %d (%d): %s",
+	syslog (LOG_ERR | LOG_DAEMON,
+		"Error reading from %s on socket %d (%zd): %s",
 		ls->str, ls->sockfd, read_bytes, strerror (read_bytes));
       return -1;
     }
 
   if (read_bytes == 0 && ls->ai.ai_socktype == SOCK_STREAM)
     {
-      syslog (LOG_DEBUG, "Peer %s disconnected on socket %d\n",
-	      ls->str, ls->sockfd);
+      syslog (LOG_DEBUG | LOG_DAEMON,
+	      "Peer %s disconnected on socket %d\n", ls->str, ls->sockfd);
       return -1;
     }
 
@@ -270,11 +281,13 @@ kdc_read (struct listenspec *ls)
       if (rc != 0)
 	strcpy (ls->clientaddrname, "unknown address");
 
-      syslog (LOG_DEBUG, "Read %d bytes from %s on socket %d\n",
+      syslog (LOG_DEBUG | LOG_DAEMON,
+	      "Read %zu bytes from %s on socket %d\n",
 	      ls->bufpos, ls->clientaddrname, ls->sockfd);
     }
   else
-    syslog (LOG_DEBUG, "Read %d bytes from %s on socket %d\n",
+    syslog (LOG_DEBUG | LOG_DAEMON,
+	    "Read %zu bytes from %s on socket %d\n",
 	    ls->bufpos, ls->str, ls->sockfd);
 
   return 0;
@@ -297,7 +310,8 @@ kdc_ready (struct listenspec *ls)
     return 1;
 
   if (ls->ai.ai_socktype == SOCK_STREAM)
-    syslog (LOG_DEBUG, "Got %d bytes of %d bytes from %s on socket %d\n",
+    syslog (LOG_DEBUG | LOG_DAEMON,
+	    "Got %zu bytes of %zu bytes from %s on socket %d\n",
 	    ls->bufpos, waitfor + 4, ls->str, ls->sockfd);
 
   return 0;
@@ -310,8 +324,8 @@ kdc_process (struct listenspec *ls)
   char *p;
   ssize_t plen;
 
-  syslog (LOG_DEBUG, "Processing %d bytes on socket %d",
-	  ls->bufpos, ls->sockfd);
+  syslog (LOG_DEBUG | LOG_DAEMON,
+	  "Processing %zu bytes on socket %d", ls->bufpos, ls->sockfd);
 
   if (ls->ai.ai_socktype == SOCK_DGRAM)
     plen = process (ls->buf, ls->bufpos, &p);
@@ -320,7 +334,8 @@ kdc_process (struct listenspec *ls)
 
   if (plen <= 0)
     {
-      syslog (LOG_ERR, "Processing request failed on socket %d", ls->sockfd);
+      syslog (LOG_ERR | LOG_DAEMON,
+	      "Processing request failed on socket %d", ls->sockfd);
       memcpy (ls->buf, fatal_krberror, fatal_krberror_len);
       ls->bufpos = fatal_krberror_len;
     }
@@ -331,7 +346,8 @@ kdc_process (struct listenspec *ls)
       free (p);
     }
 
-  syslog (LOG_DEBUG, "Generated %d bytes response for socket %d",
+  syslog (LOG_DEBUG | LOG_DAEMON,
+	  "Generated %zu bytes response for socket %d",
 	  ls->bufpos, ls->sockfd);
 }
 
@@ -345,9 +361,9 @@ ctrlc (int signum)
 
 #define MAX(a,b) ((a) > (b) ? (a) : (b))
 
-/* Main KDC logic, loop around select and call kdc_accept, kdc_read,
-   kdc_extension, kdc_process and kdc_send.  This return when the
-   SIGINT or SIGTERM signals are received. */
+/* Main KDC logic, loops around select and calls kdc_accept, kdc_read,
+   kdc_extension, kdc_process and kdc_send.  This returns when either
+   of the signals SIGINT or SIGTERM is received. */
 void
 kdc_loop (void)
 {
@@ -360,9 +376,10 @@ kdc_loop (void)
   signal (SIGTERM, ctrlc);
 
 #ifdef USE_STARTTLS
-  syslog (LOG_DEBUG, "Starting (GNUTLS `%s')", gnutls_check_version (NULL));
+  syslog (LOG_INFO | LOG_DAEMON, "Starting (GNUTLS `%s')",
+	  gnutls_check_version (NULL));
 #else
-  syslog (LOG_DEBUG, "Starting (no TLS)");
+  syslog (LOG_INFO | LOG_DAEMON, "Starting (no TLS)");
 #endif
 
   while (!quit)
@@ -377,7 +394,8 @@ kdc_loop (void)
 		{
 		  maxfd = MAX (maxfd, ls->sockfd + 1);
 		  if (!arg.quiet_flag)
-		    syslog (LOG_DEBUG, "Listening on %s (%s) socket %d\n",
+		    syslog (LOG_DEBUG | LOG_DAEMON,
+			    "Listening on %s (%s) socket %d\n",
 			    ls->str, ls->addrname, ls->sockfd);
 		  FD_SET (ls->sockfd, &readfds);
 		}
@@ -388,7 +406,8 @@ kdc_loop (void)
       if (rc < 0)
 	{
 	  if (errno != EINTR)
-	    syslog (LOG_ERR, "Error listening on sockets (%d): %s",
+	    syslog (LOG_ERR | LOG_DAEMON,
+		    "Error listening on sockets (%d): %s",
 		    rc, strerror (errno));
 	  continue;
 	}
@@ -410,5 +429,5 @@ kdc_loop (void)
 	  }
     }
 
-  syslog (LOG_DEBUG, "Shutting down");
+  syslog (LOG_INFO | LOG_DAEMON, "Shutting down");
 }
