@@ -1,5 +1,5 @@
 /* shishid.c --- Shishi Key Distribution Center daemon.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -36,9 +36,9 @@ struct listenspec *listenspec;
 char *fatal_krberror;
 size_t fatal_krberror_len;
 #ifdef USE_STARTTLS
-gnutls_dh_params dh_params;
-gnutls_anon_server_credentials anoncred;
-gnutls_certificate_credentials x509cred;
+gnutls_dh_params_t dh_params;
+gnutls_anon_server_credentials_t anoncred;
+gnutls_certificate_credentials_t x509cred;
 #endif
 
 /* Listen to all listenspec's, removing entries that fail. */
@@ -139,7 +139,7 @@ kdc_unlisten (void)
       tmp = ls->next;
 
       if (!ls->listening)
-	syslog (LOG_NOTICE,
+	syslog (LOG_NOTICE | LOG_DAEMON,
 		"Closing outstanding connection to %s on socket %d",
 		ls->str, ls->sockfd);
 
@@ -149,7 +149,8 @@ kdc_unlisten (void)
 	    printf ("Closing %s (%s)...\n", ls->str, ls->addrname);
 	  rc = close (ls->sockfd);
 	  if (rc != 0)
-	    syslog (LOG_ERR, "Could not close %s on socket %d: %s (%d)",
+	    syslog (LOG_ERR | LOG_DAEMON,
+		    "Could not close %s on socket %d: %s (%d)",
 		    ls->str, ls->sockfd, strerror (errno), errno);
 	}
 
@@ -184,8 +185,8 @@ kdc_setuid (void)
     error (EXIT_FAILURE, errno, "Cannot setuid");
 
   if (!arg.quiet_flag)
-    printf ("User identity set to `%s' (%d)...\n",
-	    passwd->pw_name, passwd->pw_uid);
+    printf ("User identity set to `%s' (%lu)...\n",
+	    passwd->pw_name, (unsigned long) passwd->pw_uid);
 }
 
 /* Create a hard coded error message that can be used in case kdc.c
@@ -485,7 +486,7 @@ const char version_etc_copyright[] =
      year.  */
   "Copyright %s %d Simon Josefsson.";
 
-static void usage (int status) __attribute__ ((__noreturn__));
+static void usage (int status) __attribute__((__noreturn__));
 
 static void
 usage (int status)
@@ -520,7 +521,7 @@ main (int argc, char *argv[])
 
   if (arg.version_given)
     {
-      version_etc (stdout, "shishid", PACKAGE_NAME, VERSION,
+      version_etc (stdout, "shishid", PACKAGE_NAME, PACKAGE_VERSION,
 		   "Simon Josefsson", (char *) NULL);
       return EXIT_SUCCESS;
     }
