@@ -1,5 +1,5 @@
 /* starttls.c --- Handle extended TCP connections (for TLS).
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -28,12 +28,12 @@
 /* This function will print information about this session's peer
  * certificate. */
 static void
-logcertinfo (gnutls_session session)
+logcertinfo (gnutls_session_t session)
 {
   time_t now = time (NULL);
-  const gnutls_datum *cert_list;
+  const gnutls_datum_t *cert_list;
   unsigned cert_list_size = 0;
-  gnutls_x509_crt cert;
+  gnutls_x509_crt_t cert;
   size_t i;
   int rc;
 
@@ -44,7 +44,8 @@ logcertinfo (gnutls_session session)
   rc = gnutls_x509_crt_init (&cert);
   if (rc < 0)
     {
-      syslog (LOG_ERR, "TLS xci failed (%d): %s", rc, gnutls_strerror (rc));
+      syslog (LOG_ERR | LOG_DAEMON, "TLS xci failed (%d): %s",
+	      rc, gnutls_strerror (rc));
       return;
     }
 
@@ -66,8 +67,8 @@ logcertinfo (gnutls_session session)
 				     GNUTLS_X509_FMT_DER);
 	if (rc < 0)
 	  {
-	    syslog (LOG_ERR, "TLS xci[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xci[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 
@@ -76,8 +77,8 @@ logcertinfo (gnutls_session session)
 				 md5fingerprint, &md5fingerprintlen);
 	if (rc != GNUTLS_E_SUCCESS)
 	  {
-	    syslog (LOG_ERR, "TLS f[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS f[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 
@@ -88,16 +89,16 @@ logcertinfo (gnutls_session session)
 	expiration_time = gnutls_x509_crt_get_expiration_time (cert);
 	if (expiration_time == (time_t) - 1)
 	  {
-	    syslog (LOG_ERR, "TLS xcget[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcget[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 
 	activation_time = gnutls_x509_crt_get_activation_time (cert);
 	if (expiration_time == (time_t) - 1)
 	  {
-	    syslog (LOG_ERR, "TLS xcgat[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcgat[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 
@@ -112,32 +113,32 @@ logcertinfo (gnutls_session session)
 	rc = gnutls_x509_crt_get_dn (cert, NULL, &subjectlen);
 	if (rc != GNUTLS_E_SUCCESS && rc != GNUTLS_E_SHORT_MEMORY_BUFFER)
 	  {
-	    syslog (LOG_ERR, "TLS xcgd[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcgd[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 	subject = xmalloc (++subjectlen);
 	rc = gnutls_x509_crt_get_dn (cert, subject, &subjectlen);
 	if (rc != GNUTLS_E_SUCCESS)
 	  {
-	    syslog (LOG_ERR, "TLS xcgd2[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcgd2[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 
 	rc = gnutls_x509_crt_get_issuer_dn (cert, NULL, &issuerlen);
 	if (rc != GNUTLS_E_SUCCESS && rc != GNUTLS_E_SHORT_MEMORY_BUFFER)
 	  {
-	    syslog (LOG_ERR, "TLS xcgid[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcgid[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 	issuer = xmalloc (++issuerlen);
 	rc = gnutls_x509_crt_get_issuer_dn (cert, issuer, &issuerlen);
 	if (rc != GNUTLS_E_SUCCESS)
 	  {
-	    syslog (LOG_ERR, "TLS xcgid2[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcgid2[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 
@@ -145,16 +146,16 @@ logcertinfo (gnutls_session session)
 	rc = gnutls_x509_crt_get_serial (cert, NULL, &seriallen);
 	if (rc != GNUTLS_E_SUCCESS && rc != GNUTLS_E_SHORT_MEMORY_BUFFER)
 	  {
-	    syslog (LOG_ERR, "TLS xcgs[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcgs[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 	serial = xmalloc (seriallen);
 	rc = gnutls_x509_crt_get_serial (cert, serial, &seriallen);
 	if (rc != GNUTLS_E_SUCCESS)
 	  {
-	    syslog (LOG_ERR, "TLS xcgs2[%d] failed (%d): %s", i,
-		    rc, gnutls_strerror (rc));
+	    syslog (LOG_ERR | LOG_DAEMON, "TLS xcgs2[%zu] failed (%d): %s",
+		    i, rc, gnutls_strerror (rc));
 	    goto cleanup;
 	  }
 
@@ -177,9 +178,10 @@ logcertinfo (gnutls_session session)
 	else
 	  validity = "valid";
 
+	/* This message can arguably belong to LOG_AUTH.  */
 	syslog (LOG_INFO, "TLS client certificate `%s', issued by `%s', "
 		"serial number `%s', MD5 fingerprint `%s', activated `%s', "
-		"expires `%s', version #%d, key %s %d bits, currently %s",
+		"expires `%s', version #%d, key %s %u bits, currently %s",
 		subject, issuer, serialhex, md5fingerprinthex,
 		activation_time_str, expiration_time_str,
 		gnutls_x509_crt_get_version (cert), keytype, bits, validity);
@@ -197,55 +199,57 @@ logcertinfo (gnutls_session session)
 
   {
     unsigned int status;
+
+    /* Accept default syslog facility for these errors.
+     * They are clearly relevant as audit traces.  */
     rc = gnutls_certificate_verify_peers2 (session, &status);
     if (rc != GNUTLS_E_SUCCESS)
       syslog (LOG_ERR, "TLS client certificate failed (%d): %s",
 	      rc, gnutls_strerror (rc));
     if (status != 0)
-      syslog (LOG_ERR, "TLS client certificate verify failure (%d)",
-	      status);
+      syslog (LOG_ERR, "TLS client certificate verify failure (%u)", status);
   }
 }
 
 /* This function will log some details of the given session. */
 static void
-logtlsinfo (gnutls_session session)
+logtlsinfo (gnutls_session_t session)
 {
-  gnutls_credentials_type cred;
+  gnutls_credentials_type_t cred;
   const char *protocol =
     gnutls_protocol_get_name (gnutls_protocol_get_version (session));
-  gnutls_kx_algorithm kx = gnutls_kx_get (session);
+  gnutls_kx_algorithm_t kx = gnutls_kx_get (session);
   const char *keyexchange = gnutls_kx_get_name (kx);
   const char *certtype =
     gnutls_certificate_type_get_name (gnutls_certificate_type_get (session));
   const char *cipher = gnutls_cipher_get_name (gnutls_cipher_get (session));
   const char *mac = gnutls_mac_get_name (gnutls_mac_get (session));
-  const char *compression =
-    gnutls_compression_get_name (gnutls_compression_get (session));
   int resumedp = gnutls_session_is_resumed (session);
 
+  /* This message can arguably belong to LOG_AUTH.  */
   syslog (LOG_INFO, "TLS handshake negotiated protocol `%s', "
 	  "key exchange `%s', certficate type `%s', cipher `%s', "
-	  "mac `%s', compression `%s', %s",
+	  "mac `%s', %s",
 	  protocol ? protocol : "N/A",
 	  keyexchange ? keyexchange : "N/A",
 	  certtype ? certtype : "N/A",
 	  cipher ? cipher : "N/A",
-	  mac ? mac : "N/A", compression ? compression : "N/A",
+	  mac ? mac : "N/A",
 	  resumedp ? "resumed session" : "session not resumed");
 
   cred = gnutls_auth_get_type (session);
   switch (cred)
     {
     case GNUTLS_CRD_ANON:
-      syslog (LOG_INFO,
+      syslog (LOG_INFO | LOG_DAEMON,
 	      "TLS anonymous authentication with %d bit Diffie-Hellman",
 	      gnutls_dh_get_prime_bits (session));
       break;
 
     case GNUTLS_CRD_CERTIFICATE:
       if (kx == GNUTLS_KX_DHE_RSA || kx == GNUTLS_KX_DHE_DSS)
-	syslog (LOG_INFO, "TLS certificate authentication with %d bit "
+	syslog (LOG_INFO | LOG_DAEMON,
+		"TLS certificate authentication with %d bits "
 		"ephemeral Diffie-Hellman",
 		gnutls_dh_get_prime_bits (session));
       logcertinfo (session);
@@ -255,7 +259,7 @@ logtlsinfo (gnutls_session session)
     case GNUTLS_CRD_PSK:
     case GNUTLS_CRD_IA:
     default:
-      syslog (LOG_ERR, "Unknown TLS authentication (%d)", cred);
+      syslog (LOG_ERR | LOG_DAEMON, "Unknown TLS authentication (%u)", cred);
       break;
     }
 }
@@ -279,6 +283,8 @@ kdc_extension (struct listenspec *ls)
 				  STARTTLS_LEN) != 0)
     return kdc_extension_reject (ls);
 
+  /* This message can arguably belong to LOG_AUTH,
+   * but leave it at the default facility.  */
   syslog (LOG_INFO, "Trying STARTTLS");
 
   memcpy (ls->buf, STARTTLS_SERVER_ACCEPT, STARTTLS_LEN);
@@ -289,39 +295,39 @@ kdc_extension (struct listenspec *ls)
   rc = gnutls_init (&ls->session, GNUTLS_SERVER);
   if (rc != GNUTLS_E_SUCCESS)
     {
-      syslog (LOG_ERR, "TLS initialization failed (%d): %s", rc,
-	      gnutls_strerror (rc));
+      syslog (LOG_ERR | LOG_DAEMON, "TLS initialization failed (%d): %s",
+	      rc, gnutls_strerror (rc));
       return -1;
     }
 
   rc = gnutls_priority_set_direct (ls->session, "NORMAL:+ANON-DH", NULL);
   if (rc != GNUTLS_E_SUCCESS)
     {
-      syslog (LOG_ERR, "TLS failed, gnutls_psd %d: %s", rc,
-	      gnutls_strerror (rc));
+      syslog (LOG_ERR | LOG_DAEMON, "TLS failed, gnutls_psd %d: %s",
+	      rc, gnutls_strerror (rc));
       return -1;
     }
 
   rc = gnutls_credentials_set (ls->session, GNUTLS_CRD_ANON, anoncred);
   if (rc != GNUTLS_E_SUCCESS)
     {
-      syslog (LOG_ERR, "TLS failed, gnutls_cs %d: %s", rc,
-	      gnutls_strerror (rc));
+      syslog (LOG_ERR | LOG_DAEMON, "TLS failed, gnutls_cs %d: %s",
+	      rc, gnutls_strerror (rc));
       return -1;
     }
 
   rc = gnutls_credentials_set (ls->session, GNUTLS_CRD_CERTIFICATE, x509cred);
   if (rc != GNUTLS_E_SUCCESS)
     {
-      syslog (LOG_ERR, "TLS failed, gnutls_cs X.509 %d: %s", rc,
-	      gnutls_strerror (rc));
+      syslog (LOG_ERR | LOG_DAEMON, "TLS failed, gnutls_cs X.509 %d: %s",
+	      rc, gnutls_strerror (rc));
       return -1;
     }
 
   gnutls_certificate_server_set_request (ls->session, GNUTLS_CERT_REQUEST);
 
   gnutls_dh_set_prime_bits (ls->session, DH_BITS);
-  gnutls_transport_set_ptr (ls->session, (gnutls_transport_ptr)
+  gnutls_transport_set_ptr (ls->session, (gnutls_transport_ptr_t)
 			    (unsigned long) ls->sockfd);
 
   gnutls_db_set_retrieve_function (ls->session, resume_db_fetch);
@@ -331,7 +337,7 @@ kdc_extension (struct listenspec *ls)
   rc = gnutls_handshake (ls->session);
   if (rc < 0)
     {
-      syslog (LOG_ERR, "TLS handshake failed (%d): %s\n",
+      syslog (LOG_ERR | LOG_DAEMON, "TLS handshake failed (%d): %s\n",
 	      rc, gnutls_strerror (rc));
       return -1;
     }
