@@ -1,5 +1,5 @@
 /* crypto-ctx.c --- Shishi crypto context self tests.
- * Copyright (C) 2002-2013 Simon Josefsson
+ * Copyright (C) 2002-2022 Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -71,9 +71,9 @@ test (Shishi * handle)
   for (i = 0; tvp = &tv[i], tvp->etype; i++)
     {
       len = shishi_cipher_randomlen (tvp->etype);
-      if (len == (size_t) - 1)
+      if (len == (size_t) -1)
 	{
-	  fail ("shishi_cipher_randomlen(%d) failed: %d\n", tvp->etype, len);
+	  fail ("shishi_cipher_randomlen(%d) failed: %zu\n", tvp->etype, len);
 	  continue;
 	}
 
@@ -85,9 +85,10 @@ test (Shishi * handle)
 	}
 
       len = shishi_cipher_blocksize (tvp->etype);
-      if (len == (size_t) - 1)
+      if (len == (size_t) -1)
 	{
-	  fail ("shishi_cipher_blocksize (%d) failed: %d\n", tvp->etype, len);
+	  fail ("shishi_cipher_blocksize (%d) failed: %zu\n", tvp->etype,
+		len);
 	  continue;
 	}
 
@@ -126,7 +127,7 @@ test (Shishi * handle)
 	  err = shishi_crypto_encrypt (ctx, in, j, &out, &len);
 	  if (err)
 	    {
-	      fail ("shishi_crypto_encrypt(etype=%d, len=%d) failed (%d)\n",
+	      fail ("shishi_crypto_encrypt(etype=%d, len=%zu) failed (%d)\n",
 		    tvp->etype, j, err);
 	      continue;
 	    }
@@ -134,7 +135,7 @@ test (Shishi * handle)
 	  err = shishi_crypto_decrypt (ctx2, out, len, &out2, &len2);
 	  if (err)
 	    {
-	      fail ("shishi_crypto_decrypt(etype=%d, len=%d) failed (%d)\n",
+	      fail ("shishi_crypto_decrypt(etype=%d, len=%zu) failed (%d)\n",
 		    tvp->etype, j, err);
 	      continue;
 	    }
@@ -154,7 +155,7 @@ test (Shishi * handle)
 	      fail ("shishi_crypto_encrypt (in1, %d) failed\n", tvp->etype);
 	      continue;
 	    }
-	  success ("shishi_crypto_encrypt/decrypt(etype=%d, len=%d) OK\n",
+	  success ("shishi_crypto_encrypt/decrypt(etype=%d, len=%zu) OK\n",
 		   tvp->etype, j);
 	}
 
